*******************************************
* 
*
*
* Stata do-file to reproduce the laboratory experiment results in Abeler/Nosenzo/Raymond "Preferences for truth-telling" (published in Econometrica)
* 

*
* Contact for lab experiments: Daniele Nosenzo, Daniele.Nosenzo@nottingham.ac.uk
* 

************************************
*
* Variables used in the paper
*
* treatment: treatment name 
* report: report 
* report1-report10: indicitor if report is equal to 1..10 for 10-state treatments
* lab: Nottingham or Oxford
* belief: belief about share of reports of 10 in the G treatments
* draw: true state in the OBSERVABLE treatment
*
********************************************





**********************************************************************
***** F_LOW vs F_HIGH ************************************************
**********************************************************************
	use truth_telling_lab_experiments_data_web_appendix.dta, clear


	keep treatment lab report
	keep if treatment=="F_LOW" | treatment=="F_HIGH"

	* test whether reports differ across labs
	gen labnum=(lab=="Oxford")
	reg report labn, r
	ttest report, by(labn)
	tab report labn, col
	
	gen report10 = (report==10)
	ttest report10, by(labn)
	tab report10 labn, col chi2
	
	* descriptive stats of proprtion of 10s acros treatments
	tab treatment, su(report10)
	
	* compute the statistic 1 minus the ratio of low reports to exp low draws
	count if treatment == "F_LOW"
	local expected_true_10s = round(0.1*r(N))
	di "`expected_true_10s'"
	gsort -treatment -report 
	drop if _n <= `expected_true_10s'
	
	count if treatment == "F_HIGH"
	local expected_true_10s = round(0.6*r(N))
	di "`expected_true_10s'"
	gsort +treatment -report 
	drop if _n <= `expected_true_10s'
	
	* descriptive stats of 1 minus the ratio of low reports to exp low draws
	tab treatment, su(report10)
	
	* regression of 1 minus the ratio of low reports to exp low draws
	gen F_HIGH=(treatment=="F_HIGH")
	reg report10 F_HIGH, robust
	tab report10 F_HIGH, chi2

	
	* graph of 1 minus the ratio of low reports to expected low draws
	cibar report10, over1(F_HIGH) bargap(15) barlabel(on) blposition(ne) /*
	*/ barcolor(gs7 gs7) ciopts(lcolor(black))graphopts(ysc(r(0)) /*
	*/ ytitle("1 minus the ratio of low reports to expected low draws") /*
	*/ ylabel(0(.2)1, nogrid) legend(off) graphregion(color(white)))
	*** NOTE: need to enter labels manually, F_LOW at 1.1 and F_HIGH at 2.3
	*** as well as legend of CI
	


****  regressions of 1 minus the ratio of low reports to exp low draws, separately for the two labs

	use truth_telling_lab_experiments_data_web_appendix.dta, clear

	keep treatment lab report
	keep if treatment=="F_LOW" | treatment=="F_HIGH"
	
	gen labnum=(lab=="Oxford")
	gen report10 = (report==10)
	gen F_HIGH=(treatment=="F_HIGH")
		
	foreach labn in 0 1 {
	
		preserve
			keep if labn == `labn'
			
			* compute the statistic 1 minus the ratio of low reports to exp low draws
			count if treatment == "F_LOW"
			local expected_true_10s = round(0.1*r(N))
			di "`expected_true_10s'"
			gsort -treatment -report 
			drop if _n <= `expected_true_10s'
			
			count if treatment == "F_HIGH"
			local expected_true_10s = round(0.6*r(N))
			di "`expected_true_10s'"
			gsort +treatment -report 
			drop if _n <= `expected_true_10s'
			
			reg report10 F_HIGH if labn==`labn', robust
			tab report10 F_HIGH if labn==`labn', chi2

		restore
	
	}
	
	
	
	
		

**********************************************************************
**********************************************************************
**********************************************************************







**********************************************************************
***** G_LOW vs G_HIGH ********************************************
**********************************************************************

	use truth_telling_lab_experiments_data_web_appendix.dta, clear


	keep treatment belief report
	keep if treatment=="G_LOW" | treatment=="G_HIGH"
	gen G_HIGH=(treatment=="G_HIGH")
	
	* graph of beliefs
	twoway (histogram belief if G_HIGH==0, frac start(0) /*
	*/ width(5) color(ltblue)) (histogram belief if G_HIGH==1, frac /*
	*/ start(0) width(5) fcolor(none) lcolor(red)), legend(order(1 "G_LOW" /*
	*/ 2 "G_HIGH" )) graphregion(color(white)) ylabel(,nogrid) /*
	*/ xtitle("Share of subjects expected to report 10")  /*
	*/ ytitle("Relative frequency")
	
	* descriptive and regression analysis of beliefs
	tab treatment, su(belief)
	reg belief G_HIGH, r
	ranksum belief, by(G_HIGH)
	
	* descriptive stats of proprtion of 10s across treatments
	gen report10=(report==10)
	tab treatment, su(report10)
	
	* graph of of proprtion of 10s acros treatments
	cibar report10, over1(G_HIGH) bargap(15) barlabel(on) blposition(ne) /*
	*/ barcolor(gs7 gs7) ciopts(lcolor(black))graphopts(ysc(r(0)) /*
	*/ ytitle("Share of subjects reporting 10") ylabel(0(.2)1, /*
	*/ nogrid) yline(0.1, lcolor(black) lpattern(dash)) /*
	*/ legend(off) graphregion(color(white)))
	**** NEED TO REPLACE YLINE MANUALLY TO MAKE IT STAND ON FRONT
	*** need to enter labels manually, G_LOW at 1.1 and G_HIGH at 2.3
	
	* regression analysis of proprtion of 10s across treatments
	regress report10 G_HIGH, r
	ivregress 2sls  report10 ( belief = G_HIGH), r
	tab report10 G_HIGH, chi2
	
	* analysis of correlation beliefs/reports
	tab report10 treatment, su(belief)
	ranksum belief if G_HIGH==0, by(report10)
	ranksum belief if G_HIGH==1, by(report10)


**********************************************************************
**********************************************************************
**********************************************************************





**********************************************************************
***** OBSERV vs UNOBSERV *********************************************
**********************************************************************

	use truth_telling_lab_experiments_data_web_appendix.dta, clear



	keep treatment report draw
	keep if treatment=="OBSERVABLE" | treatment=="UNOBSERVABLE" /*
	*/ | treatment=="robustOBSERVABLE"
	gen OBS=(treatment=="OBSERVABLE")
	replace OBS=2 if treatment=="robustOBSERVABLE"

		
	* graph of reports across treatments
	twoway (histogram report if treatment=="UNOBSERVABLE", /*
	*/ discrete start(1) fcolor(ltblue) lcolor(ltblue) lpattern(blank)) /*
	*/ (histogram report if treatment=="OBSERVABLE", discrete start(1) /*
	*/ fcolor(none) lcolor(red)) (pci .1 0 .1 10.5,  lcolor(black) /*
	*/ lpattern(dash)), xscale(range(1 10)) xlabel(1(1)10) /*
	*/ legend(order(1 "UNOBSERVABLE" 2 "OBSERVABLE" )) graphregion(color(white))/*
	*/ ylabel(,nogrid) xtitle("Report") ytitle("Relative frequency") 
	
	* analysis of difference across treatments
	tab report treatment if OBS!=2
	ksmirnov report if OBS!=2, by(OBS) 
	reg report  OBS if OBS!=2, r
	ranksum report if OBS!=2, by(OBS)
	
	* analysis of robustOBSERVABLE
	tab report treatment if OBS!=0
	ksmirnov report if OBS!=0, by(OBS) 
	reg report  OBS if OBS!=0, r
	ranksum report if OBS!=0, by(OBS)

		
	* graph of downwards lying in OBSERVABLE
	keep if treatment=="OBSERVABLE"
	contract draw report, freq(freq)
	twoway (scatter report draw [fweight = freq], sort mcolor(dknavy) /*
	*/ msymbol(circle)), yscale(range(1 10)) ylabel(#10, grid glcolor(gs13) /*
	*/ gmin gmax gextend) xscale(range(1 10)) xlabel(#10, grid glcolor(gs13)) /*
	*/ graphregion(fcolor(white))


**********************************************************************
**********************************************************************
**********************************************************************





**********************************************************************
***** F10_LOW vs F10_HIGH ********************************************
**********************************************************************

use truth_telling_lab_experiments_data_web_appendix.dta, clear




	aorder
	keep treatment report report1-report10
	keep if treatment=="F10_LOW" | treatment=="F10_HIGH"
	gen reportabove6=(report>6)
	gen F10_HIGH=(treatment=="F10_HIGH")
	
	* descriptive stats and regression of proportion reporting above 6
	tab treatment, su(reportabove6)
	reg reportabove6 F10_HIGH, robust
	tab reportabove6 F10_HIGH, chi2
	
	* graph of distribution of reports
	graph  bar report1-report10 , stack over(treatment, sort(F10_HIGH)) /*
	*/ graphregion(color(white)) ylabel(,nogrid) legend(off) /*
	*/ ytitle("Cumulative share") blabel(name, position(center)) /*
	*/ yvaroptions(relabel(1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6" 7 /*
	*/ "7" 8 "8" 9 "9" 10 "10")) bar(7, color(gs13)) bar(8, color(gs12)) /*
	*/ bar(9, color(gs11))  bar(10, color(gs10))


**********************************************************************
**********************************************************************
**********************************************************************





**********************************************************************
***** KR addtional prediction test ***********************************
**********************************************************************

	use truth_telling_lab_experiments_data_web_appendix.dta, clear

	keep report treatment
	keep if treatment=="robustKRhigh" | treatment=="robustKRlow"
	
	replace treatment="KR_HIGH" if treatment=="robustKRhigh"
	replace treatment="KR_LOW" if treatment=="robustKRlow"
	
	tab treatment, su(report)
	
	tab treatment, gen(tdum)


	reg report tdum1, robust
	ranksum report, by(tdum1)
	


**********************************************************************
**********************************************************************
**********************************************************************
