*******************************************
* 
*
*
* Stata do-file to reproduce the meta study results in Abeler/Nosenzo/Raymond "Preferences for truth-telling" (published in Econometrica)
* and to export data for the website www.preferencesfortruthtelling.com
* 
* This do-file has been run with Stata 14.2. Additional commands loaded include reghdfe version 5.2.10. 
*
* Contact for meta study: Johannes Abeler, johannes.abeler@economics.ox.ac.uk
*
* 
**********************************************
*
* Variables used in the paper
*
*** id variables
* authors: ID of research paper/study
* treatment: ID of treatment
* id: ID of subject
* matching_group: ID of matching group (almost always == id)
*
*** payoff/report variables
* payoff_per_round_ppp: expected payoff for a given round of the experiment, in USD (converted by PPP)
* payoff_min_report_per_round_ppp: expected payoff if reporting the lowest possible state, in USD
* payoff_max_report_per_round_ppp: expected payoff if reporting the highest possible state, in USD
* payoff_mm: maximal payoff from misreporting, i.e., difference between the two previous variables
* payoff_truthful_report_per_r_ppp: expected payoff of truthful reporting, in USD
* standardized_report_per_round: standardized report (see paper for exact formula)
*
*** treatment-level variables
* true_distribution: distribution of states (1DX: uniform draw with X outcomes. NDX: sum of N uniform draws with X outcomes. 1D2asy: non-uniform draw with two outcomes)
* true_distribution_text: distribution of states (coarser classification)
* repeated: dummy ==1 if experiment has more than one round/report
* student: dummy ==1 if subject is a student
* remote: dummy ==1 if experiment was done remotely (by phone or online) 
* internal_lying: dummy ==1 if report was about state of mind (as in "mind game" of Jiang 2013) 
* control_rolls: dummy ==1 if subjects were encouraged to roll die several times
* country: country where experiment took place
* info_about_past_others: dummy == 1 if info about behavior of other subjects available
* subject_as_victim: dummy ==1 if report reduces payoff of another subject
* experiment_year: year experiment was conducted
* author_affiliation: affiliation of majority of authors (economics, psychology, sociology)
* method_of_randomization: coin toss, die roll or draw from urn
* total_reports: number of reports (=rounds) a subject had to do in the experimen
* handcoded: dummy ==1 if data was extracted from paper
* rawdata: dummy ==1 if data was provided by original authors
* roundsimputed: dummy =1 if we only have the average report over several reports and not the reports by round
*
*** individual-level variables
* female: dummy ==1 if subject is female
* age: age of subject in years 
* student_econ/student_psy/student_other: dummy = 1 if subject studies economics/psychology/something else
* round: round of experiment
*
*** paper-level variables
* citation: citation of paper
* paper_title: title of paper
* weblink: link to paper
*
*
*
********************************************





{/* Initialize */
*******************************************************************************************	
	
	* set this to the folder containing the meta-study data
	global root_folder = "C:\"

	* you can create separate sub folders for data and output
	global folder = "${root_folder}"
	global paper_graph_folder = "${root_folder}"
	global website_export_folder = "${root_folder}"
	
	cd "$folder"

	do truth_telling_meta_study_programs_web_appendix.do 	// load helper programs


	global treatment_level_vars = "payoff_mm  repeated remote control_rolls internal_lying info_about_past_others subject_as_victim student experiment_year "
	global individual_level_vars = "female age student_econ student_psy student_other"

}

{/* merge the two data files and calculate remaining variables */

	* load data file that contains one line per subject
	use "meta_study_data_by_subject.dta", clear
	

	* merge it with data file that contains one line per treatment
	merge m:1 treatment using "meta_study_data_by_treatment.dta"
	tab treatment _merge if _merge != 3
	keep if _merge == 3 
	drop _merge
	

	encodeAndReplace treatment // to be able to use treatment fixed effects
	
	replace handcoded = 0 if handcoded == .
	replace handcoded = 0 if inlist(authors, "Chytilova,Korbel", "Fosgaard,Hansen,Piovesan", "Houser,List,Piovesan,Samek,Winter", "Khachatryan,Frank,Buehren,Beck") // we partly handcode these studies but have the raw data
	replace rawdata = 1 if handcoded == 0 
	replace rawdata = 0 if rawdata == .
	
	* fill in student_econ etc. variables from treatment data on subject pools
	replace student_econ = 1 if subject_pool == "students (econ)" 
	replace student_psy = 0 if subject_pool == "students (econ)" 
	replace student_other = 0 if subject_pool == "students (econ)" 
	
	
	* variables per round
	genAndLabel payoff_per_round_ppp = payoff_per_round/ppp, label("Expected payoff per round (in 2015 USD)")
	genAndLabel payoff_min_report_per_round_ppp = payoff_min_report_per_round/ppp, label("Expected payoff from reporting minimally per round (in 2015 USD)")
	genAndLabel payoff_max_report_per_round_ppp = payoff_max_report_per_round/ppp, label("Expected payoff from reporting maximally per round (in 2015 USD)")
	genAndLabel payoff_truthful_report_per_r_ppp = payoff_truthful_report_per_round/ppp, label("Expected payoff from reporting truthfully per round(in 2015 USD)")

	* variables across rounds (not used in paper)
	genAndLabel total_payoff_ppp = total_payoff/ppp, label("Expected payoff across all rounds (in 2015 USD)")
	genAndLabel payoff_min_report_ppp = payoff_min_report/ppp, label("Expected payoff from reporting minimally across all rounds (in 2015 USD)")
	genAndLabel payoff_max_report_ppp = payoff_max_report/ppp, label("Expected payoff from reporting maximally across all rounds (in 2015 USD)")
	genAndLabel payoff_truthful_report_ppp = payoff_truthful_report/ppp, label("Expected payoff from reporting truthfully across all rounds (in 2015 USD)")


	* distance between max and min report as measure of incentives
	genAndLabel payoff_mm = payoff_max_report_per_round_ppp - payoff_min_report_per_round_ppp, label("Maximal payoff from misreporting")

	
	* gen standardized payoff variables (hat tip to David Sturrock)
	genAndLabel standardized_report_per_round = (payoff_per_round_ppp - payoff_truthful_report_per_r_ppp) / cond(payoff_per_round_ppp < payoff_truthful_report_per_r_ppp, (payoff_truthful_report_per_r_ppp - payoff_min_report_per_round_ppp), (payoff_max_report_per_round_ppp - payoff_truthful_report_per_r_ppp)), label("Standardized report per round")
	genAndLabel standardized_report_acr_rounds = (total_payoff_ppp - payoff_truthful_report_ppp) / cond(total_payoff_ppp < payoff_truthful_report_ppp, (payoff_truthful_report_ppp - payoff_min_report_ppp), (payoff_max_report_ppp - payoff_truthful_report_ppp)), label("Standardized report across rounds") 

	* some standardized_reports have floating point errors
	foreach var in standardized_report_per_round standardized_report_acr_rounds {
		replace `var' = round(`var', 0.00001)
		replace `var' = 1 if `var' > 0.999 & `var' < 1.001
		replace `var' = -1 if `var' > -1.001 & `var' < -0.999
	}
	
	assert standardized_report_per_round >= -1 & standardized_report_per_round <= 1
	assert (standardized_report_acr_rounds >= -1 & standardized_report_acr_rounds <= 1) | standardized_report_acr_rounds == .


	order _all, alpha

	save12 truth_telling_meta_study_merged_data.dta, replace


}



	
{/*** create table of CDF and PDF by treatment used in several graphs */
*******************************************************************************************		
	
	use truth_telling_meta_study_merged_data.dta, clear	

	* these studies have non-linear payoff increases, the standardized_reports are thus not on the usual points (e.g., not on -1, -.6, -.2, .2, .6 and 1 for 1D6)
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment)
	drop if inlist(authors, "Blanco,Charness,Ezquerra,Rodriguez-Lara")
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // treatments change round by round, so standardized_report by subjects not really comparable
	
	gen subjects = cond(roundsimputed == 0, 1/total_reports, 1) // for "roundsimputed==1" data we have one line per subject and not total_reports lines; data with round==. has also total_reports lines per subject
	replace standardized_report_per_round = round(standardized_report_per_round, 0.001)
	collapse (sum) subjects (first) payoff_max_report_per_round_ppp payoff_min_report_per_round_ppp true_distribution total_reports citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by(treatment standardized_report_per_round) // collapse over id's within treatment and report

	
	total subjects

	* generate an entry with frequency 0 if frequency of an outcome is 0
	egen tag_report_dist = tag(standardized_report_per_round true_distribution) 
	bysort true_distribution: egen number_per_dist = total(tag_report_dist)
	egen tag_treat = tag(treatment)
	expand number_per_dist+1 if tag_treat, gen(expanded)
	bysort treatment expanded: replace standardized_report_per_round = -1 + 2*(_n-1)/(number_per_dist-1) if expanded
	replace standardized_report_per_round = round(standardized_report_per_round, 0.001)
	replace subjects = 0 if expanded
	bysort treatment standardized_report_per_round: egen max_frequency = max(subjects)
	drop if round(subjects,0.001) < round(max_frequency,0.001)
	drop if inlist(treatment, "DGV COLOURED LAB+FIELD":treatment, "DGV COLOURED STUDENTS":treatment) & standardized_report_per_round == 0 // these treatments have non linear payoff increase and this sr is added incorrectly
	

	total subjects
	
	bysort treatment: egen total_freq = total(subjects)
	
	gen actual_pdf = subjects/total_freq	// share of subjects reporting each point in the PDF
	
	* only focus on 1D2, 1D3, 1D6, 1D10, 1D100 where we have enough data
	gen true_pdf = cond(true_distribution == "1D6", 1/6, cond(true_distribution=="1D2", 1/2, cond(true_distribution=="1D3", 1/3, cond(true_distribution=="1D10", 1/10, cond(true_distribution=="1D100", 1/100, .))))) 
	keep if true_pdf != . 
		
	sort treatment standardized_report_per_round
	
	by treatment: gen actual_cdf = sum(actual_pdf)
	by treatment: gen true_cdf = sum(true_pdf)
	
	save12 temp_pdf_cdf_data.dta, replace
}
	




{/*** Average amount of lying and summary statistics */
*******************************************************************************************	


	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	
	
	countNumberDecisions
	postToFile, file("stat_number_of_decisions") fmt("%5.0f") value(`=r(N)')
	distinct id
	postToFile, file("stat_number_of_subjects") fmt("%5.0f") value(`=r(ndistinct)')
	postToFile, file("stat_number_of_subjects_rounded_down_to_1000") fmt("%5.0f") value(`=floor(r(ndistinct)/1000)*1000')
	
	distinct treatment
	postToFile, file("stat_number_of_treatments") fmt("%5.0f") value(`=r(ndistinct)')
	distinct authors
	postToFile, file("stat_number_of_studies") fmt("%5.0f") value(`=r(ndistinct)')

	preserve
		drop if inlist(country, "", "Online (US and Indian users)") 
		distinct country
		postToFile, file("stat_number_of_countries") fmt("%5.0f") value(`=r(ndistinct)')
	restore
	

	preserve
		collapse (first) rawdata, by(authors)
		count if rawdata==1
		postToFile, file("stat_number_of_studies_with_rawdata") fmt("%5.0f") value(`=r(N)')
	restore
	
	mean standardized_report_per_round, vce(cluster matching_group)
	postToFile, file("stat_mean_standardized_report") fmt("%5.3f") value(`=_b[standardized_report_per_round]')
	postToFile, file("stat_mean_standardized_report_lower_ci") fmt("%5.3f") value(`=_b[standardized_report_per_round] - 1.96*_se[standardized_report_per_round]')
	postToFile, file("stat_mean_standardized_report_upper_ci") fmt("%5.3f") value(`=_b[standardized_report_per_round] + 1.96*_se[standardized_report_per_round]')
	postToFile, file("stat_mean_standardized_report_as_percent") fmt("%5.1f") value(`=100*_b[standardized_report_per_round]')
	
	preserve
		collapse (mean) standardized_report_per_round (first) matching_group, by(id)
		mean standardized_report_per_round, vce(cluster matching_group)
		postToFile, file("stat_mean_standardized_report_weighted_by_subject") fmt("%5.3f") value(`=_b[standardized_report_per_round]')
	restore
	
	
	
	*** Share of world GDP and population that our countries cover 

	* raw data downloaded from http://databank.worldbank.org/data/reports.aspx?source=world-development-indicators&l=en#
	* Series: GDP: "GDP (current US$)" Population: "Population, total" 
	* Year: 2015

	

	import excel "${folder}\Data_Extract_From_World_Development_Indicators.xlsx", clear firstrow case(lower)

	keep countryname seriesname yr2015
	drop if seriesname == "" | yr2015 == ".."

	encodeAndReplace seriesname

	codebook seriesname
	destring yr2015, replace

	reshape wide yr2015, i(countryname) j(seriesname) 

	rename yr20151 gdp
	rename yr20152 population
	rename countryname country
	replace country = "DR Congo" if country == "Congo, Dem. Rep."
	replace country = "Russia" if country == "Russian Federation"
	replace country = "Slovakia" if country == "Slovak Republic"
	replace country = "South Korea" if country == "Korea, Rep."
	replace country = "USA" if country == "United States"


	merge 1:m country using truth_telling_meta_study_merged_data.dta, keepusing(citation)
	keep if _merge == 3 | country == "World" 

	drop citation _merge
	egen tag = tag(country)
	keep if tag

	foreach var in gdp population {
		sum `var' if country != "World"
		local total = r(sum)
		sum `var' if country == "World"
		di 100*`total'/r(mean)

		postToFile, file("stat_share_of_`var'_in_percent") fmt("%5.0f") value(`=100*`total'/r(mean)')

	}
	
	
	
	
}	
	
{/*** Figure 1 */
*******************************************************************************************	


		use truth_telling_meta_study_merged_data.dta, clear
		replaceFrequencies1D2asy
	
		* we will use authors variable as part of variable name later, so drop all special characters 
		replace authors = subinstr(authors, ",", "", .)
		replace authors = subinstr(authors, "-", "", .)
		replace authors = subinstr(authors, " ", "", .)
		replace authors = substr(authors, 1, 20)
		
		*** collapse data and prepare variables for website export
		gen subjects = 1
		genAndLabel repeated = cond(total_reports>1, 1, 0), label("Repeated reports")
		replace country = "" if country == "Online (US and Indian users)"
	
		collapse (mean) standardized_report_per_round payoff_mm (sum) subjects (first) citation repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by(id treatment authors ) // collapse to individual subjects (i.e., collapse multiple decisions within subject)
		replace subjects = 1 if id!= "" // for averages over individuals, treat as one observation and set frequency equal to 1. Leave frequency unchanged where no id as these are from handmade tables and do represent multiple people.
		collapse (mean) standardized_report_per_round payoff_mm (sum) subjects (first) citation repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by(treatment authors) // collapse to treatment average

		* add legend as additional circles
		set obs `=_N + 3' 
		replace standardized_report_per_round = -0.95 in `=_N-2'
		replace standardized_report_per_round = -0.89 in `=_N-1'
		replace standardized_report_per_round = -0.83 in `=_N'
		replace payoff_mm = 25 in `=_N-2'/`=_N'
		replace authors = "legend" in `=_N-2'/`=_N'
		replace subjects = 50 in `=_N-2'
		replace subjects = 100 in `=_N-1'
		replace subjects = 200 in `=_N'
		gen legend_label = ""
		replace legend_label = "50 subjects" in `=_N-2'
		replace legend_label = "100 subjects" in `=_N-1'
		replace legend_label = "200 subjects" in `=_N'
		
		sort payoff_mm
		

		* combine graph command 
		local graph_command `"scatter standardized_report_per_round payoff_mm if treatment == "FFH BASELINE":treatment , msymbol(none) mlabel(treatment) mlabposition(8) mlabsize(vsmall) mlabcolor(black) "' 
		levelsof authors
		foreach t in `r(levels)' {
			capture drop series_`t'
			qui gen series_`t' = standardized_report_per_round if authors == `"`t'"'
			local connect_option = "" // connect dots for studies that change incentive level
			local graph_command `"`graph_command' || scatter series_`t' payoff_mm [weight=subjects], `connect_option' msize(*.2) "'
		}
	
		* add legend
		local graph_command `"`graph_command' || scatter standardized_report_per_round payoff_mm [weight=subjects] if authors == "legend", msize(*.2) msymbol(none) mlabel(legend_label) mlabposition(3) mlabgap(*2) mlabsize(vsmall) mlabcolor(black)"'

		* add FFH BASELINE
		capture drop series_FFH_BASELINE
		qui gen series_FFH_BASELINE = standardized_report_per_round if treatment == "FFH BASELINE":treatment
		local graph_command `"`graph_command' || scatter series_FFH_BASELINE payoff_mm [weight=subjects] , msymbol(Oh) mcolor(black) msize(*.2) "'
		local graph_command `"`graph_command' || scatter standardized_report_per_round payoff_mm if treatment == "FFH BASELINE":treatment , mlabel(treatment) mlabposition(8) mlabsize(vsmall) mlabcolor(black) "'
		
		* run graph command
		qui graph twoway `graph_command' legend(off) graphregion(color(white)) ylabel(-1(0.5)1, nogrid) ytitle("Standardized report") xtitle("Maximal payoff from misreporting (in 2015 USD)") xlabel(0.1 "0.1" 1 5 10(10)50) xscale(log) yline(0, lcolor(black) lpattern(shortdash))

		*** export graph
		graph export "${paper_graph_folder}/figure1.png", width(3000) replace

		*** export data for website
		drop legend_label 
		export delimited using "${website_export_folder}/data_iframe_1a.csv", replace 

}
		
		
	
{/*** Testing Finding 1 */
*******************************************************************************************	


	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	

	// at 0.1% level, can test down to 0.25 (cl(matching_group)) or  0.38 (cl(authors)) 
	foreach cluster in matching_group authors {
		reg standardized_report_per_round, cl(`cluster')
		foreach level in 0.5 0.4 0.38 0.37 0.25 0.24 {
			test _cons = `level'
			display "Ho: coef <= `level' p-value = " ttail(r(df_r),sqrt(r(F)))
		}
	}
	

}
	
	

{/*** Figure 2 */
*******************************************************************************************	
	
	* 1D6
	use temp_pdf_cdf_data.dta, clear

	keep if true_distribution == "1D6" 
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
	
	drop if total_freq < 10 // drop treatments that have 9 or fewer subjects
	
	* calculate confidence interval
	sum subjects
	local total_subjects = `r(sum)'
	bysort standardized_report_per_round: egen subjects_at_this_sr = total(subjects)
	gen overall_pdf = subjects_at_this_sr/`total_subjects'
	gen se = sqrt(overall_pdf*(1-overall_pdf)/`total_subjects')
	gen overall_pdf_lower_ci = overall_pdf - 1.96*se
	gen overall_pdf_upper_ci = overall_pdf + 1.96*se
	
	local graph_command = "function y=1/6 , range(-1 1) lcolor(black) lpattern(shortdash) "
	levelsof treatment
	foreach t in `r(levels)' {
		capture drop pdf_`t'
		qui gen pdf_`t' = actual_pdf if treatment ==`t'
		local graph_command = `"scatter pdf_`t' standardized_report_per_round [weight=total_freq] , connect(l) lwidth(vvthin) msize(*.3) || `graph_command' "'
	}
	
	* add overall average and CI
	local graph_command = `" `graph_command' || scatter overall_pdf standardized_report_per_round, connect(l) msymbol(none) lwidth(medthick) color(black) "'
	local graph_command = `" twoway rarea overall_pdf_lower_ci overall_pdf_upper_ci standardized_report_per_round, color(gs10) lwidth(none) || `graph_command' "'


	sort standardized_report_per_round treatment
	qui `graph_command' xtitle("Standardized report (six states)") ytitle("Probability mass function") legend(off) ylabel(0(0.2)0.8, nogrid) xlabel(-1 (.4) 1) graphregion(color(white)) plotregion(m(b=0)) saving(1D6.gph, replace)




	* 1D2
	use temp_pdf_cdf_data.dta, clear
	keep if true_distribution == "1D2" 

	drop if total_freq < 10 // drop treatments that have 9 or fewer subjects

	* calculate confidence interval
	sum subjects
	local total_subjects = `r(sum)'
	bysort standardized_report_per_round: egen subjects_at_this_sr = total(subjects)
	gen overall_pdf = subjects_at_this_sr/`total_subjects'
	gen se = sqrt(overall_pdf*(1-overall_pdf)/`total_subjects')
	gen overall_pdf_lower_ci = overall_pdf - 1.96*se
	gen overall_pdf_upper_ci = overall_pdf + 1.96*se
	
	keep if standardized_report_per_round < -0.99 // only show left most bubble in graph
	
	* add confidence interval data
	set obs `=_N+2'
	replace standardized_report_per_round = -1.025 in `=_N'
	replace standardized_report_per_round = -0.975 in `=_N-1'
	
	foreach var in overall_pdf overall_pdf_lower_ci overall_pdf_upper_ci {
		sum `var'
		replace `var' = `r(mean)' in `=_N'
		replace `var' = `r(mean)' in `=_N-1'
	}
	
	local graph_command = "function y=1/2 , range(-1.05 -0.95) lcolor(black) lpattern(shortdash) "
	levelsof treatment
	foreach t in `r(levels)' {
		capture drop pdf_`t'
		qui gen pdf_`t' = actual_pdf if treatment ==`t'
		local graph_command = `"scatter pdf_`t' standardized_report_per_round [weight=total_freq] , connect(l) lwidth(vvthin) msize(*.3) || `graph_command' "'
	}

	* add overall average and confidence interval
	local graph_command = `" `graph_command' || scatter overall_pdf standardized_report_per_round, connect(l) msymbol(none) lwidth(medthick) color(black) "'
	local graph_command = `" twoway rarea overall_pdf_lower_ci overall_pdf_upper_ci standardized_report_per_round, color(gs10) lwidth(none) || `graph_command' "'

	sort standardized_report_per_round

	qui `graph_command' , xtitle("(two states)") ytitle("") legend(off) ylabel(0(0.2)0.8, nogrid) xlabel(-1) graphregion(color(white)) plotregion( m(b=0)) fxsize(15) saving(1D2.gph, replace)
	
	graph combine 1D6.gph 1D2.gph, graphregion(color(white)) imargin(l=10 r=10) ycommon
	
	graph export "${paper_graph_folder}/figure2.png", width(3000) replace


	capture erase 1D2.gph
	capture erase 1D6.gph


	* post share of subjects included in figure 2
	use truth_telling_meta_study_merged_data.dta, clear	
	distinct id if (true_distribution=="1D6" | true_distribution == "1D2") & ! inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
	local ids_included = `r(ndistinct)'
	distinct id
	postToFile, file("stat_share_subjects_included_in_figure2") fmt("%5.0f") value(`=100*`ids_included'/`r(ndistinct)'')

	
	
	
	*** Figure 2 (for 2, 6, 10 states): export for website
	
	foreach states in 2 3 6 10 {
		
		use temp_pdf_cdf_data.dta, clear

		if `states' == 2 {
			keep if true_distribution == "1D2" 
			*drop if round(standardized_report_per_round, .01) != -1 & round(standardized_report_per_round, .01) != 1
			local iframe_tab "b"
		}
		if `states' == 3 {
			keep if true_distribution == "1D3" 
			drop if round(standardized_report_per_round, .01) == 0
			local iframe_tab "c"
			}
		else if `states' == 6 {
			keep if true_distribution == "1D6" 
			drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
			local iframe_tab "a"		
		}
		else if `states' == 10 {
			keep if true_distribution == "1D10" 
			local iframe_tab "d"
		}
		
		drop if total_freq < 10 // drop treatments that have 9 or fewer subjects
		

		* add overall average 
		bysort standardized_report_per_round: egen overall_percent = total(subjects)
		sum subjects
		replace overall_percent = 100*overall_percent/`r(sum)'
		
		gen percent = 100*actual_pdf
		
		capture drop subjects
		rename total_freq subjects
		keep standardized_report_per_round treatment subjects percent* citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink
		export delimited using "${website_export_folder}/data_iframe_2`iframe_tab'.csv", replace 

	}
	
	
	
}	
	

{/*** Testing Finding 2 */
*******************************************************************************************	


	use truth_telling_meta_study_merged_data.dta, clear	

	* these studies have non-linear payoff increases, the standardized_reports are thus not on the usual points (e.g., not on -1, -.6, -.2, .2, .6 and 1 for 1D6)
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment)
	drop if inlist(authors, "Blanco,Charness,Ezquerra,Rodriguez-Lara")
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // treatments change round by round, so standardized_report by subjects not really comparable
	drop if true_distribution == "1D6imputed"
	
	replace standardized_report_per_round = round(standardized_report_per_round, 0.001)

	* drop very small treatments
	egen id_tag = tag(id)
	bysort treatment: egen subjects_per_treatment = total(id_tag)
	drop if subjects_per_treatment < 10

	keep standardized_report_per_round true_distribution id treatment round matching_group authors
	collapseAll, meanVars(standardized_report_per_round) byVars(id treatment round) // treat each round as a separate decision and avoid that averaging by id leads to intermediate sr's

	drop if true_distribution == "1D2asy" // this is actually many different distributions
	bysort true_distribution: egen modal_sr = mode(standardized_report_per_round), maxmode

	gen sr_is_equal_to_modal_sr = cond(round(standardized_report_per_round, 0.01)==round(modal_sr, 0.01), 1, 0)
	
	local highest_threshold = 0
	levelsof true_distribution
	foreach t in `r(levels)' {
		di _n _n _n _n "True_distribution: `t' "
		sum sr_is_equal_to_modal_sr if true_distribution == "`t'"
		local likelihood_modal_sr = ceil(`r(mean)'*100)/100 // round up to next 0.01
		
		reg sr_is_equal_to_modal_sr if true_distribution == "`t'", cluster (matching_group)
		
		forvalues level = `likelihood_modal_sr'(0.01)1 {
			di _n _n "True_distribution `t': testing cutoff value `level'"
			
			test _cons == `level' 
			if `r(p)' <0.001 {
				if `level' > `highest_threshold' {
					local highest_threshold = `level'
				}
				di "Successfully tested against 0.001"
				continue, break
			}
			
			
		}
	}
	

	di "Highest threshold (cluster on matching_group): `highest_threshold'"


	* clustering on author for 1D2 and 1D6
	local highest_threshold = 0
	foreach t in "1D2" "1D6" {
		di _n _n _n _n "True_distribution `t'"
		sum sr_is_equal_to_modal_sr if true_distribution == "`t'"
		local likelihood_modal_sr = ceil(`r(mean)'*100)/100 // round up to next 0.01
		
		reg sr_is_equal_to_modal_sr if true_distribution == "`t'", cluster (authors)
		
		forvalues level = `likelihood_modal_sr'(0.01)1 {
			di _n _n "True_distribution `t' cutoff value `level'"
			
			test _cons == `level' 
			if `r(p)' <0.001 {
				if `level' > `highest_threshold' {
					local highest_threshold = `level'
				}
				di "Successfully tested against 0.001"
				continue, break
			}
			
			
		}
	}
	
	di "Highest threshold (cluster on author): `highest_threshold'"	



	
	
	

}

	
{/*** Testing Finding 3 */
*******************************************************************************************	


	**** correlation between the payoff of a given state and its likelihood of being reported
	use temp_pdf_cdf_data.dta, clear

	local highest_p = 0
	levelsof true_distribution
	foreach td in `r(levels)' {
		di "true_distribution: `td'"
		reg actual_pdf standardized_report_per_round [aweight=total_freq]	if true_distribution == "`td'"
		local p = round((2 * ttail(e(df_r), abs(_b[standardized_report_per_round]/_se[standardized_report_per_round]))), 0.001) 

		if `p' > `highest_p' {
			local highest_p = round(`p', 0.001) 
		}
	}
	
	di "Highest p: `highest_p'"

	local test_statistic = `highest_p'
	if round(`test_statistic', 0.001) == 0 {
		postToFile, file("stat_fact3_sr_corr_with_pdf_highest_p_value") fmt("%5.3f") value(0.001)
	}
	else {
		postToFile, file("stat_fact3_sr_corr_with_pdf_highest_p_value") fmt("%5.3f") value(`=`test_statistic')')
	}



	*** report-to-report changes

	use truth_telling_meta_study_merged_data.dta, clear	

	* these studies have non-linear payoff increases, the standardized_reports are thus not on the usual points (e.g., not on -1, -.6, -.2, .2, .6 and 1 for 1D6)
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment)
	drop if inlist(authors, "Blanco,Charness,Ezquerra,Rodriguez-Lara")
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // treatments change round by round, so standardized_report by subjects not really comparable
	
	keep if inlist(true_distribution, "1D2", "1D3", "1D6", "1D10") // 1D100 has not full support as too little data

	replace standardized_report_per_round = round(standardized_report_per_round*1000, 1)	// to avoid fixed-point rounding mistakes, multiple by 1000 and round to 1
	
	levelsof true_distribution 
	foreach t in `r(levels)' { /* loop over all four true_distributions */
			
		preserve
			keep if true_distribution == "`t'"
			
			foreach cluster in "matching_group" "authors" {	/* cluster on id or authors */
				if "`cluster'" == "authors" & ("`t'"== "1D3" | "`t'"== "1D10") continue  // but only cluster on authors for 1D2 and 1D6, as other distributions have too little data
				di _n _n _n _n _n "True distribution: `t' - clustering on `cluster'"
				
				levelsof standardized_report_per_round,  local(sr_levels)
				foreach sr in `sr_levels' {	/* run mlogit with all standardized_reports as base level - see whether next standardized_report up is more likely and significantly so */
					if `sr' == 1000 continue // no need to run it on the highest standardized_report as there is no next standardized_report
 					di "`=round(`sr', 0.01)'"
					mlogit standardized_report_per_round , baseoutcome(`sr') vce(cluster `cluster')
				}		
			}
		
		restore
		
	}	
	
	
}	
	
	
	


{/*** Testing Finding 4 */
*******************************************************************************************	


	* we test for all true_distribution with at least four states whether there are any non-maximal reports that are reported more often than their true likelihood
	* and if yes, whether they are significanlty higher
	* we then find the lowest p-value for each true_distribution and from those find the highest lowest p-value across all distributions
	
	

	use truth_telling_meta_study_merged_data.dta, clear	

	drop if inlist(true_distribution, "1D2", "1D2asy", "1D6imputed", "1D3", "2D2") // at least four states
	drop if roundsimputed == 1 // we have only average report per subject not what they reported in each round

	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
	drop if inlist(authors, "Blanco,Charness,Ezquerra,Rodriguez-Lara") // these treatments have non-linear increases
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // total_reports does not match data as treatments change from round to round

	replace standardized_report_per_round = round(standardized_report_per_round, 0.001)
	
	
	* drop all distributions with less than 2 treatments
	egen tag = tag(treatment)
	bysort true_distribution: egen treatments = total(tag)
	drop if treatments < 2 & true_distribution != "1D100" 
	drop treatments tag
	

	
	preserve // 1D6 with cluster on study: we just consider only one observation per study, works like maximal clustering
	
		keep if true_distribution == "1D6"
		gen report5 = cond(round(standardized_report_per_round, 0.01) == 0.6, 1,0)
		bysort authors: egen share5 = mean(report5)
		egen tag = tag(authors)
		
		ttest share5 == 0.16667 if tag == 1

	restore
	

	
	gen frequency = 1
	collapse (sum) frequency (first) report true_distribution authors, by(standardized_report_per_round treatment) // treat each round as separate decision; we only have repeated observations for 1D6, all others are oneshot

	bysort treatment: egen total_freq = total(frequency) //total frequency per treatment
	gen actual_pdf = frequency/total_freq	//share of subjects reporting each point in the PDF

	* calculating true_pdf
	gen true_pdf = cond(true_distribution == "1D6", 1/6, cond(true_distribution=="1D10", 1/10, cond(true_distribution == "1D2", 0.5, cond(true_distribution == "1D3", 1/3, cond(true_distribution == "1D100", 1/100, .)))))
	foreach rep in 2 4 5 6 20 30 {
		replace true_pdf = binomialp(`rep',report,0.5) if true_distribution == "`rep'D2"	
	}
	replace true_pdf = cond(report <= 7, report - 1, 13 - report)/36 if true_distribution == "2D6"
	assert true_pdf !=.
	
	gen diff_pdf = actual_pdf - true_pdf
	
	distinct true_distribution
	local number_of_tds_left_to_tick_off = `r(ndistinct)'
	
	* calculating the lowest p-value for each sr above true_pdf for each distribution
	local highest_lowest_p = 0
	levelsof true_distribution
	foreach td in `r(levels)' {
		di " "
		
		local lowest_p_`td' = 1
		local first_time_this_td = 1 // to tick off each td once
		qui levelsof standardized_report_per_round if true_distribution == "`td'"
		foreach sr in `r(levels)' {
			
			* we only want to test sr that are reported more often than their true_pdf and only at non-maximal sr, thus continue for the other sr's
			qui sum diff_pdf if true_distribution == "`td'" & round(standardized_report_per_round, 0.01) == round(`sr', 0.01)
			local mean = round(`r(mean)', 0.001)
			if r(mean) < 0 | `sr' > 0.99 {
				continue 
			} 
			local number_of_tds_left_to_tick_off = `number_of_tds_left_to_tick_off' - `first_time_this_td' // check that each true_distribution has at least one sr above true_pdf
			local first_time_this_td = 0
			gen reported_this_sr = cond(round(standardized_report_per_round, 0.01) == round(`sr', 0.01), 1, 0)
			qui sum true_pdf if true_distribution == "`td'" & round(standardized_report_per_round, 0.01) == round(`sr', 0.01)
			qui bitest reported_this_sr == `r(mean)' [fweight=frequency] if true_distribution == "`td'"
			if r(p) < `lowest_p_`td'' {
				local lowest_p_`td' = r(p)
			}
			
			
			di "`td' - SR: `=round(`sr', 0.01)' - r(mean) `mean' p: `=round(`r(p)', 0.001)'"
			
			
			drop reported_this_sr
		
		}
		if `lowest_p_`td'' > `highest_lowest_p' {
				local highest_lowest_p = `lowest_p_`td''
		}
	}


	if `number_of_tds_left_to_tick_off' > 0 local highest_lowest_p = 1 // if there is any true_distribution without any non-maximal lying set that p-value to 1 (which brings the highest_lowest_p to 1)

	di "highest lowest p: `=round(`highest_lowest_p', 0.001)'; number of true_distribution without any non-maximal lying: `number_of_tds_left_to_tick_off'"

	
	local test_statistic = `=round(`highest_lowest_p', 0.001)'
	if round(`test_statistic', 0.001) == 0 {
		postToFile, file("stat_fact4_highest_lowest_p_value_across_distributions") fmt("%5.3f") value(0.001)
	}
	else {
		postToFile, file("stat_fact4_highest_lowest_p_value_across_distributions") fmt("%5.3f") value(`=`test_statistic')')
	}
		
	
}
	
		
	
	
{/*** Figure A.1 */
*******************************************************************************************	

	* prepare world map data from shape file
	cd "$folder"
	
	preserve
		shp2dta using "ne_110m_admin_0_countries", data(worlddata) coor(worldcoor) genid(id) genc(c) replace
		use worlddata.dta, clear
		gen country = name
		save12 worlddata.dta, replace
		cd "$folder"
	restore
	
	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	
	drop if country == "" | country == "Online (US and Indian users)"
	replace country = "United States" if country == "USA"
	replace country = "Czech Rep." if country == "Czech Republic"
	replace country = "Korea" if country == "South Korea"
	replace country = "Dem. Rep. Congo" if country == "DR Congo"
			


	*** collapse data
	gen subjects = 1
	collapse (mean) standardized_report_per_round (sum) subjects , by(id country) // collapse to individual subjects (i.e., collapse multiple decisions within subject)
	replace subjects = 1 if id!= "" // for averages over individuals, treat as one observation and set frequency equal to 1. Leave frequency unchanged where no id as these are from handmade tables and do represent multiple people.
	collapse (mean) standardized_report_per_round (sum) subjects , by( country) // collapse to country average


	merge 1:1 country using "worlddata.dta"
	replace standardized_report_per_round = . if _merge != 3
	
	spmap standardized_report_per_round using "worldcoor.dta" if admin!="Antarctica", id(id) fcolor(Heat) clnumber(16) legenda(off) 
	graph export "${paper_graph_folder}/figure_A1.png", width(3000) replace

		
	* export for website
	export delimited using "${website_export_folder}/data_iframe_3a.csv", replace

	
	capture erase worlddata.dta
	capture erase worldcoor.dta
	capture erase ne_110m_admin_0_countries.prj
		
}
	




	
	
{/*** Table A.1 */
*******************************************************************************************		

	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	prepareDatasetForTables

	keep standardized_report_per_round $treatment_level_vars $individual_level_vars id treatment authors author_aff true_distribution country method_of_rand matching_group roundsimputed total_reports
	gen decisions = 1
	replace decisions = total_reports if roundsimputed==1
	
	collapseAll, byVars(id) sumVars(decisions) meanVars(standardized_report_per_round)
	egen total_decisions = total(decisions)	

	eststo clear
	local file = "${paper_graph_folder}/table_A1.tex"

	label var standardized_report_per_round "Standardized report"
	label var payoff_mm "Maximal payoff from misreporting (in 2015 USD)"
	
	local individual_level_vars1 = "female age "
	local individual_level_vars2 = "student_econ student_psy student_other"
			
	eststo clear
	
	estpost summarize $treatment_level_vars
	estout using "`file'", cells("mean(fmt(3)) count(fmt(0))") style(tex)	collabels(none) mlabels(none) nonum label replace prehead("\begin{tabular}{l*{1}{cc}}\hline\hline \\ & Mean& $\#$ Subjects \\ \hline Treatment-level variables \\ \\")
	
	decode author_affiliation, gen(author_text)
	
	genAndLabel author1 = cond(author_text == "ECONOMICS", 1, 0), label("\hspace{0.3cm} 1 if economics")
	genAndLabel author2 = cond(author_text == "PSYCHOLOGY", 1, 0), label("\hspace{0.3cm} 1 if psychology")
	genAndLabel author3 = cond(author_text == "SOCIOLOGY" | author_text == "ANTHROPOLOGY", 1, 0), label("\hspace{0.3cm} 1 if sociology/anthropology")
			
	estpost summarize author1 author2 author3
	estout using "`file'", cells("mean(fmt(3)) count(fmt(0))") style(tex)	collabels(none) mlabels(none) nonum label append prehead("Author affiliation \\")

	decode method_of_randomization, gen(mod_text)

	genAndLabel mor1 = cond(mod_text == "COIN TOSS", 1, 0), label("\hspace{0.3cm} 1 if coin toss")
	genAndLabel mor2 = cond(mod_text == "DIE ROLL", 1, 0), label("\hspace{0.3cm} 1 if die roll")
	genAndLabel mor3 = cond(mod_text == "DRAW FROM URN", 1, 0), label("\hspace{0.3cm} 1 if draw from urn")
	
	estpost summarize mor1 mor2 mor3
	estout using "`file'", cells("mean(fmt(3)) count(fmt(0))") style(tex)	collabels(none) mlabels(none) nonum label append prehead("Method of randomization \\")

	decode true_distribution, gen(true_dist_text)
	
	genAndLabel true_dist2 = cond(true_dist_text == "1D2", 1, 0), label("\hspace{0.3cm} 1 if two outcomes uniform")
	genAndLabel true_dist1 = cond(true_dist_text == "1D2ASY", 1, 0), label("\hspace{0.3cm} 1 if two outcomes non-uniform")
	genAndLabel true_dist4 = cond(true_dist_text == "BELL SHAPED", 1, 0), label("\hspace{0.3cm} 1 if bell shaped")
	genAndLabel true_dist3 = cond(true_dist_text == "OTHER UNIFORM", 1, 0), label("\hspace{0.3cm} 1 if other uniform")

	estpost summarize true_dist1 true_dist2 true_dist3 true_dist4
	estout using "`file'", cells("mean(fmt(3)) count(fmt(0))") style(tex)	collabels(none) mlabels(none) nonum label append prehead("True distribution \\")

	estpost summarize `individual_level_vars1'
	estout . using "`file'", cells("mean(fmt(3)) count(fmt(0))") style(tex)	collabels(none) mlabels(none) nonum label append prehead("\\ \hline Individual-level variables \\ \\")

	foreach var of varlist `individual_level_vars2' {
		label variable `var' `"\hspace{0.3cm} `: variable label `var''"'
	}
	estpost summarize `individual_level_vars2'
	estout . using "`file'", cells("mean(fmt(3)) count(fmt(0))") style(tex)	collabels(none) mlabels(none) nonum label append prehead("Field of study \\") postfoot("\hline \\")

	use truth_telling_meta_study_merged_data.dta, clear
	
	distinct id
	estadd local n_id = "`=r(ndistinct)'"
	distinct treatment
	estadd local n_treatment = "`=r(ndistinct)'"
	distinct authors 
	estadd local n_studies = "`=r(ndistinct)'"
	countNumberDecisions
	estadd local n_dec = "`=r(N)'", replace
	
	estout using "`file'", append style(tex) cells(none) stats(n_dec n_id n_treatment n_studies, fmt(0 0 0 0 ) labels("$\#$ Decisions" "$\#$ Subjects" "$\#$ Treatments" "$\#$ Studies" )) label mlabels(,none)	postfoot("\hline\hline \end{tabular} ")
	

}
	

{/*** Table A.2 */
*******************************************************************************************		

	******* Kitchen sink regression

	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	prepareDatasetForTables
	
	fvset base frequent _all
	
	eststo clear
	foreach cluster in matching_group authors {

		eststo: reghdfe standardized_report_per_round $treatment_level_vars , absorb(author_affiliation method_of_randomization country true_distribution) vce(cluster `cluster')
		postToFile, file("stat_payoff_mm_coefficient_kitchen_sink") fmt("%5.3f") value(`=_b[payoff_mm]')
		local payoff_mm_coefficient_ks = `=_b[payoff_mm]'
		estadd local author_aff_fe "Yes" , replace
		estadd local true_dist_fe "Yes" , replace
		estadd local mor_fe "Yes" , replace
		estadd local country_fe "Yes" , replace
		estadd local study_fe "No" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "No", replace

	}
	
	
	*** how much of between treatment variation is explained by country FE
	preserve
		egen id_tag = tag(id)
		collapse (sum) id_tag (mean) standardized_report_per_round (first) $treatment_level_vars author_affiliation method_of_randomization true_distribution country, by(treatment)
		
		* regression with all covariates except country
		reghdfe standardized_report_per_round $treatment_level_vars [aweight = id_tag], absorb(author_affiliation method_of_randomization true_distribution) 
		postToFile, file("stat_adjusted_r2_explained_bynon_country_variables") fmt("%5.3f") value(`=e(r2_a)')
		
		* regression with all covariates including country
		reghdfe standardized_report_per_round $treatment_level_vars [aweight = id_tag], absorb(author_affiliation method_of_randomization true_distribution country) 
		postToFile, file("stat_adjusted_r2_explained_by_all_variables_including_country") fmt("%5.3f") value(`=e(r2_a)')
		
	restore
	


	
	
	******** Individual regressions using study FE


		fvset base frequent _all


	**** payoff_mm	
		loadDataDropGroupsWOVariation, targetVar(payoff_mm) groupVar(authors) // load only those studies that have variation in the target_var
		
		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments
		drop if inlist(authors, "ABELER,BECKER,FALK":authors, "ABELER,NOSENZO,RAYMOND":authors, "COHN,FEHR,MARECHAL":authors, "CONRADS,IRLENBUSCH,RILKE,WALKOWITZ":authors,"FISCHBACHER,UTIKAL":authors, "HANNA,WANG":authors, "PLONER,REGNER":authors, "SHALVI,ELDAR,BEREBY-MEYER":authors, "GAECHTERSCHULZ":authors, "EFFRONBRYANMURNIGHAN":authors, "HRUSCHKA ET AL":authors, "POTTERSSTOOP":authors, "WEISEL,SHALVI":authors, "DUCH,SOLAZ":authors, "GNEEZY,KAJAKAITE,SOBEL":authors)
		drop if inlist(treatment, "KG UNOBSERVED GAME":treatment, "SGM MULTIPLE_ROLLS":treatment)
		
		tab authors
		tab treatment
		distinct treatment 
		postToFile, file("stat_number_treatments_in_payoff_regression") fmt("%5.0f") value(`=r(ndistinct)')
		
		replace country = "other" if inlist(country, "", "Online (US and Indian users)") 
		encodeAndReplace country
		rename student student2
		rename internal_lying internal_lying2
		rename subject_as_victim subject_as_victim2
		decode treatment, gen(treatment_text)
		gen previous_effort = cond(strpos(treatment_text, "EXTENDED")!=0, 1, 0)
		gen announced_incentive_change = cond(strpos(treatment_text, "(ANNOUNCED)")!=0, 1, 0)
		
		eststo: reghdfe standardized_report_per_round payoff_mm student2 internal_lying2 subject_as_victim2 previous_effort announced_incentive_change, absorb(authors country /* round */) vce(cluster matching_group)
		postToFile, file("stat_payoff_mm_coefficient_study_fe") fmt("%5.3f") value(`=_b[payoff_mm]')
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "Yes" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "Yes", replace

	


	**** remote vs lab	
		loadDataDropGroupsWOVariation, targetVar(communication_channel) groupVar(authors) // load only those studies that have variation in the target_var
		decode communication_channel, gen(comm_text)
		
		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments
		drop if inlist(authors, "ABELER,NOSENZO,RAYMOND":authors, "HILBIG,ZETTLER":authors, "PASCUAL-EZAMA ET AL":authors, "COHN,GESCHE,MARECHAL":authors)
		drop if inlist(treatment, "ABF 1-COIN-TELEPHONE":treatment, "ABF 4-COIN-TELEPHONE":treatment, "KW INFORMED DUO ROUND 1":treatment, "KW INFORMED DUO ROUND 2":treatment, "KW UNINFORMED DUO":treatment )
		
		tab authors
		tab treatment
		
		decode treatment, gen(treatment_text)
		gen kw_uninformed = cond(strpos(treatment_text, "KW UNINFORMED")!=0, 1, 0)
		
		eststo: reghdfe standardized_report_per_round remote kw_uninformed, absorb(authors) vce(cluster matching_group)
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "No" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"	
		estadd local add_controls "No", replace
		


			
		
		
	**** control_rolls
		loadDataDropGroupsWOVariation, targetVar(control_rolls) groupVar(authors) // load only those studies that have variation in the target_var
		
		tab treatment

		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments
		decode treatment, gen(treatment_text)
		gen ga_creative = cond(strpos(treatment_text, "CREATIVE EXP")!=0, 1, 0)
		gen ga_high = cond(strpos(treatment_text, "HIGH EXP")!=0, 1, 0)
		gen ga_low = cond(strpos(treatment_text, "LOW EXP")!=0, 1, 0)

		eststo: reghdfe standardized_report_per_round control_rolls time_pressure ga_creative ga_high ga_low, absorb(authors) vce(cluster matching_group)
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "No" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "Yes", replace
		
		


	**** internal_lying
		loadDataDropGroupsWOVariation, targetVar(internal_lying) groupVar(authors) // load only those studies that have variation in the target_var

		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments		
		drop if inlist(treatment, "KG UNOBSERVED GAME":treatment)
		
		tab treatment
		
		rename payoff_mm payoff_mm2 		// we rename such that the coefficient is not shown in the table (shown as "Additional controls: Yes") 
		rename subject_as_victim subject_as_victim2

		decode treatment, gen(treatment_text)
		gen previous_effort = cond(strpos(treatment_text, "EXTENDED")!=0, 1, 0)
		
		eststo: reghdfe standardized_report_per_round internal_lying payoff_mm2 subject_as_victim2 previous_effort, absorb(authors) vce(cluster matching_group)	
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "No" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'", replace
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "Yes", replace

		
	**** info_about_past_others
		loadDataDropGroupsWOVariation, targetVar(info_about_past_others) groupVar(authors) // load only those studies that have variation in the target_var

		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments		
		drop if inlist(treatment, "BH BASELINE":treatment, "DPR FH (2008) FIRST ROUND":treatment)	

		tab treatment
		
		gen bh_authentic = cond(inlist(treatment, "BH AUTHENTIC_CHEATING":treatment, "BH AUTHENTIC":treatment, "BH AUTHENTIC_CHEATED":treatment), 1, 0)
		gen kw_duo = cond(inlist(treatment, "KW INFORMED DUO ROUND 2":treatment, "KW UNINFORMED DUO":treatment), 1, 0)
		gen kw_single = cond(inlist(treatment, "KW INFORMED SINGLE ONLINE ROUND 2":treatment, "KW UNINFORMED SINGLE ONLINE":treatment), 1, 0)

		eststo: reghdfe standardized_report_per_round info_about_past_others bh_authentic kw_duo kw_single, absorb(authors ) vce(cluster matching_group)	
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "No" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "Yes", replace
		
		

	**** subject_as_victim	
		loadDataDropGroupsWOVariation, targetVar(subject_as_victim) groupVar(authors) // load only those studies that have variation in the target_var

		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments		
		drop if inlist(authors, "PLONER,REGNER":authors)
		drop if inlist(treatment, "KG UNOBSERVED GAME":treatment, "MGRSP NO PENALTY":treatment, "FFH DOUBLE ANONYMOUS":treatment, "FFH 4.9":treatment, "FFH HIGH STAKE":treatment)
		
		tab authors
		tab treatment
		
		decode treatment, gen(treatment_text)
		gen previous_effort = cond(strpos(treatment_text, "EXTENDED")!=0, 1, 0)
		rename payoff_mm payoff_mm2
		rename internal_lying internal_lying2
		
		eststo: reghdfe standardized_report_per_round subject_as_victim payoff_mm2 internal_lying2 previous_effort, absorb(authors) vce(cluster matching_group)
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "No" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "Yes", replace


	
	**** student
		loadDataDropGroupsWOVariation, targetVar(student) groupVar(authors) // load only those studies that have variation in the target_var

		* A couple of studies vary payoff level and another variable independently. In the regression, we control for those other variables and mark this as “Additional controls: Yes” in the table. If we cannot properly control for within-study variation, we exclude the affected treatments		
		drop if inlist(authors, "ABELER,BECKER,FALK":authors, "HILBIG,ZETTLER":authors)
		decode treatment, gen(treatment_text)
		gen CFM_treatment = cond(strpos(treatment_text, "TREATMENT") != 0 & authors=="COHN,FEHR,MARECHAL":authors, 1, 0)
		
		tab authors
		tab treatment
		
		replace country = "other" if inlist(country, "", "Online (US and Indian users)") 
		encodeAndReplace country
		rename payoff_mm payoff_mm2
		
		eststo: reghdfe standardized_report_per_round student payoff_mm2 CFM_treatment, absorb(authors country) vce(cluster matching_group)
		estadd local author_aff_fe "No" , replace
		estadd local mor_fe "No" , replace
		estadd local true_dist_fe "No" , replace
		estadd local country_fe "Yes" , replace
		estadd local study_fe "Yes" , replace
		countNumberDecisions
		estadd local n_decisions = "`r(N)'"
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"
		estadd local add_controls "Yes", replace	
				
		
		
	#delimit ;
	esttab using "${paper_graph_folder}/table_A2.tex", replace keep( $treatment_level_vars ) order($treatment_level_vars )
	style(tex) substitute(_ \_) 
	cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.1 ** 0.05 *** 0.01) 
	stats(add_controls author_aff_fe mor_fe true_dist_fe country_fe study_fe n_decisions n_id n_treatment n_studies N_clust, fmt(0 ) 
	labels("Additional controls" "Author affiliation FE" "Randomization method FE " "True distribution FE" "Country FE" "Study FE" "$\#$ Decisions" "$\#$ Subjects" "$\#$ Treatments" "$\#$ Studies" "$\#$ Clusters" )) 
	label
	varlabels(3.communication_channel "1 if online/telephone" internal_lying "1 if reporting about state of mind" payoff_mm "Maximal payoff from misreporting") 
	extracols( 3 ) varwidth(35) mlabels(none ) collabels(none) eqlabels(none) 
	prehead("\begin{onehalfspace} \begin{small} \begin{center} \resizebox{20cm}{!} { \begin{tabular}{l*{10}{c}} \hline \\ \multicolumn{4}{l}{Dependent variable: Standardized report} \\ ") 
	postfoot(" \hline \end{tabular} } \end{center} \begin{flushleft} Notes: OLS regressions. Robust standard errors clustered on individual subjects (on studies in column 2) are in parentheses. The sample in columns 3 to 7 is restricted to those studies in which the independent variable of interest varies. Maximal payoff from misreporting is the difference of the highest and lowest potential payoff (converted by PPP to 2015 USD). The fixed effects control for author affiliation (economics, psychology, sociology), randomization method (die roll, coin toss, draw from urn), true distribution (asymmetric with two outcomes, uniform with two outcomes, other uniform, bell shaped), country and/or study. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{small} \end{onehalfspace}");
	#delimit cr
	
	

}	


{/*** Testing for treatment effect heterogeneity in the effect of incentive level (Table A.2) */
*******************************************************************************************	

* If we restrict the sample to only those papers that experimentally vary payoff_mm and use study FE, then the coefficient is +0.003 (this uses 94 treatments) 
* If we use all available treatments (thus using between study variation), the coefficient is -0.005

* Here, we randomly select 94 treatments from the entire sample, run the between-study regression and count how often the coefficient is larger than +0.003


	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	prepareDatasetForTables
	

	fvset base frequent _all
	label drop _all
	

	set seed 928472
	
	readFromFile, file("stat_number_treatments_in_payoff_regression") local("number_treatments") // import number reported in paper from file
	local number_treatments = r(number_treatments)
	di "`number_treatments'"
	
	distinct treatment
	local n_treat = r(ndistinct)
	
	capture drop treat_tag			// tag one observation per treatment
	egen treat_tag = tag(treatment)
	
	* run between-study regression on random 94-treatment subsamples
	local total_reps = 20 // set total_reps to 10000 to replicate result in paper
	forval rep= 1/`total_reps' {
			di "Rep: `rep'"
			capture drop random 
			capture drop temp_insample insample

			qui gen random = runiform() if treat_tag == 1
			gsort -treat_tag +random // sort first the tagged observations, randomly ordered

			gen temp_insample = cond(_n <= `number_treatments', 1, 0) // first `number_treatments' (=94) treatments are in the sample
			bysort treatment: egen insample = max(temp_insample) // propagate insample variable to all observations of the included treatments

			 capture  qui  reghdfe standardized_report_per_round $treatment_level_vars if insample == 1, absorb(author_affiliation  method_of_randomization  country true_distribution  ) vce(cluster matching_group)
			if _rc continue /* in very few cases reghdfe does not converge, in that case we ignore this repetition */
			di "`rep': " _b[payoff_mm]
			local b`rep' = _b[payoff_mm]

	} 

	
	************************ 
	* saving b's to a file
	
	
	drop _all
	drop if 1
	gen b = .

	set obs `=`total_reps''
	forval rep= 1/`total_reps' {
		if "`b`rep''" != "" { /* in case reghdfe didn't converge */
			qui replace b = `b`rep'' in `rep'	

		}
	}
	
	save12 effect_heterogeneity_b_reps_`total_reps'.dta, replace
	
	* see how many simulated coefficients are above the within-study coefficient
	readFromFile, file("stat_payoff_mm_coefficient_study_fe") local("within_study_coefficent") 
	local within_study_coefficent = r(within_study_coefficent)
	di "`within_study_coefficent'"
	
	count if b > `within_study_coefficent'
	di "Share of effects greater `within_study_coefficent': " `=r(N)/_N'
	postToFile, file("stat_percent_incentive_effect_bigger_than_within_study_coefficent_MC_`total_reps'") fmt("%5.0f") value(`=100*r(N)/_N')
		

	

	
}

	





{/*** Figure A.2 */
*******************************************************************************************	

	* collapse data
	use truth_telling_meta_study_merged_data.dta, clear	

	keep if true_distribution == "1D6" 
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
		
	gen subjects = cond(roundsimputed == 0, 1/total_reports, 1)	// for "roundsimputed==1" data we have one line per subject and not total_reports lines
	collapse (sum) subjects, by(payoff_mm standardized_report_per_round) // collapse over id's within payoff_mm and report
	
	xtile payoff_mm_quartile = payoff_mm [weight=subjects], nquantiles(4)
	bysort payoff_mm_quartile: egen min_payoff_mm_within_quartile = min(payoff_mm)
	bysort payoff_mm_quartile: egen max_payoff_mm_within_quartile = max(payoff_mm)
	
	replace min_payoff_mm_within_quartile = 0 if payoff_mm_quartile == 1
	replace max_payoff_mm_within_quartile = ceil(max_payoff_mm_within_quartile) if payoff_mm_quartile == 4
	
	replace min_payoff_mm_within_quartile = round(min_payoff_mm_within_quartile, 0.01)
	replace max_payoff_mm_within_quartile = round(max_payoff_mm_within_quartile, 0.01)	

	collapse (sum) subjects (first) min_payoff_mm_within_quartile max_payoff_mm_within_quartile, by(payoff_mm_quartile standardized_report_per_round) // collapse to payoff_mm_quartile and report

	bysort payoff_mm_quartile: egen total_freq = total(subjects)
	gen actual_pdf = subjects/total_freq	// share of subjects reporting each point in the PDF
	sort payoff_mm_quartile standardized_report_per_round // sort is needed for sum() in next lines
	

	*** graph command
	local graph_command = "function y=1/6 , range(-1 1) lcolor(black) lpattern(shortdash) "

	
	levelsof payoff_mm_quartile
	foreach q in `r(levels)' {
		capture drop pdf_`q'
		gen pdf_`q' = actual_pdf if payoff_mm_quartile ==`q'
		local graph_command = `"scatter pdf_`q' standardized_report_per_round , msymbol(Oh) msize(*2) connect(l) lwidth(vvthin) mlabel(payoff_mm_quartile) mlabcolor(black) mlabposition(0) || `graph_command' "'

	}
		
	qui `graph_command' xtitle("Standardized report") ytitle("Probability mass function") legend(off) ylabel(0(0.2)0.4, nogrid) xlabel(-1 (.4) 1) plotregion( m(b=0)) graphregion(color(white)) note("") 
	graph export "${paper_graph_folder}/figure_A2.png", width(3000) replace

	
	* export for website
	forval q=1/4{
		gen percent_`q' = 100*pdf_`q'
	}
	gen percent = 100*actual_pdf
	
	keep standardized_report_per_round payoff_mm_quartile min_payoff_mm_within_quartile max_payoff_mm_within_quartile percen*
	export delimited using "${website_export_folder}/data_iframe_1b.csv", replace 

	
}	
	


	
{/*** Figure A.3 */
*******************************************************************************************	

	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	
	drop if roundsimputed == 1 // these papers have multiple rounds but we only know the overall average
	drop if round == .
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // treatments change round by round, so not really comparable
	
	gen subjects = 1
	collapse (mean) standardized_report_per_round (sum) subjects (first) total_reports citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by (treatment round)
	
	* some treatments are not repeated but are still not in round 1 (e.g., AbelerNosenzo, DieckmanPrezpiorkaRauhut) we drop round > 1
	bysort treatment: gen nobs = _N
	drop if nobs == 1 & round != 1
	
	* add legend as additional circles
	set obs `=_N + 3' 
	replace standardized_report_per_round = -0.95 in `=_N-2'
	replace standardized_report_per_round = -0.89 in `=_N-1'
	replace standardized_report_per_round = -0.83 in `=_N'
	replace round = 32 in `=_N-2'/`=_N'
	replace treatment = 10000 in `=_N-2'/`=_N'
	replace subjects = 50 in `=_N-2'
	replace subjects = 100 in `=_N-1'
	replace subjects = 200 in `=_N'
	gen legend_label = ""
	replace legend_label = "50 subjects" in `=_N-2'
	replace legend_label = "100 subjects" in `=_N-1'
	replace legend_label = "200 subjects" in `=_N'

	
	
	* build graph command
	local graph_command " " /* "function y = 0, range(1 `=50') lcolor(black) lpattern(shortdash) " */
	levelsof treatment
	foreach t in `r(levels)' {
		capture drop series_`t'
		qui gen series_`t' = standardized_report_per_round if treatment ==`t'
		local connect_option = cond(`t' == 10000, "", "connect(l) lwidth(vvthin)") 
		local graph_command `"`graph_command' || scatter series_`t' round [weight=subjects] , `connect_option' msize(*.2) "'
	}
	
	* add legend
	local graph_command `"`graph_command' || scatter standardized_report_per_round round [weight=subjects] if treatment == 10000, msymbol(none) msize(*.2) mlabel(legend_label) mlabposition(3) mlabgap(*2) mlabsize(vsmall) mlabcolor(black)"'

	
	qui graph twoway `graph_command' legend(off) graphregion(color(white)) ylabel(-1(0.5)1, nogrid) ytitle("Standardized report") xtitle("Round") xlabel(1 5 10(10)60) xscale(log) yline(0, lcolor(black) lpattern(shortdash))
	graph export "${paper_graph_folder}/figure_A3.png", width(3000) replace

	* export for website
	drop if treatment == 10000
	drop nobs
	export delimited using "${website_export_folder}/data_iframe_5.csv", replace 

	
}
	

	
{/*** Figure A.4 */
*******************************************************************************************	
	
		use truth_telling_meta_study_merged_data.dta, clear
		replaceFrequencies1D2asy
		
		drop if country == "" | country == "Online (US and Indian users)"
		replace country = "UK" if country == "United Kingdom"

		
		* we will use authors variable as part of variable name later, so drop all special characters 
		replace authors = subinstr(authors, ",", "", .)
		replace authors = subinstr(authors, "-", "", .)
		replace authors = subinstr(authors, " ", "", .)
		replace authors = subinstr(authors, ".", "", .)
		replace authors = substr(authors, 1, 20)
		
		*** collapse data
		gen subjects = 1
		collapse (mean) standardized_report_per_round (sum) subjects (first) citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title weblink, by(id treatment authors country) // collapse to individual subjects (i.e., collapse multiple decisions within subject)
		replace subjects = 1 if id!= "" // for averages over individuals, treat as one observation and set frequency equal to 1. Leave frequency unchanged where no id as these are from handmade tables and do represent multiple people.
		collapse (mean) standardized_report_per_round (sum) subjects (first) citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title weblink, by(treatment authors country) // collapse to treatment average

		gen temp_weighted_report = standardized_report_per_round*subjects
		bysort country: egen temp_avg_report_by_country = total(temp_weighted_report)
		bysort country: egen temp_subjects_by_country = total(subjects)
		gen avg_report_by_country = temp_avg_report_by_country/temp_subjects_by_country
		drop temp_weighted_report temp_avg_report_by_country temp_subjects_by_country
		
		* encode country as numerical variable (to use it on axis) but sorted by avg_report_by_country
		egen country_rank = axis(avg_report_by_country country), label(country)

		* combine graph command 				
		distinct country
		local number_of_countries = `r(ndistinct)'	
		
		local graph_command " " 
		encodeAndReplace authors
		levelsof authors
		foreach t in `r(levels)' {
			capture drop series_`t'
			qui gen series_`t' = standardized_report_per_round if authors == `t'
			local graph_command `"`graph_command' || scatter series_`t' country_rank [weight=subjects], msize(*.3) "'
		}
	

		qui graph twoway `graph_command' || scatter avg_report_by_country country_rank, mlwidth(medthick) msymbol(plus) mcolor(black) msize(vlarge) legend(off) graphregion(color(white)) ylabel(-0.5(0.5)1, nogrid) ytitle("Standardized report") xtitle("") yline(0, lcolor(black) lpattern(shortdash)) xlabel(1(1)`number_of_countries',valuelabel angle(45) labsize(vsmall)) 
		graph export "${paper_graph_folder}/figure_A4.png", width(3000) replace

		* export for website
		drop avg_report_by_country
		label drop country_rank
		export delimited using "${website_export_folder}/data_iframe_3b.csv", replace 

		
		
}
	

	
{/*** Table A.3 */
*******************************************************************************************	

	local specification = `" "round" "female" "age" "age age_squared" "student_econ student_psy"  "'
	local vars = "round female age age_squared student_econ student_psy "	
	

	
	eststo clear 
	foreach spec in `specification' {

		local first_var `spec'
	
		if "`spec'" == "age age_squared" {
			local first_var "age"
		}

		if "`spec'" == "student_econ student_psy" {
			local first_var "student_econ"
		}

		loadDataDropGroupsWOVariation, targetVar(`first_var') groupVar(treatment) // load only those treatments that have variation in the target_var
	
		if "`spec'" == "round" {
			drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop")	// round not working for these papers as treatment changes by round
		}
					
		tab authors
		
		genAndLabel age_squared = age*age, label("Age squared")

		eststo: reghdfe standardized_report_per_round `spec' , absorb(treatment) vce(cluster matching_group)
		if "`spec'" == "female" {
			postToFile, file("stat_gender_coefficient") fmt("%5.3f") value(`=-_b[female]')
		}
		
		estadd local treatment_fe "Yes", replace
		countNumberDecisions
		estadd scalar n_decisions = `=r(N)', replace
		distinct id
		estadd local n_id = "`=r(ndistinct)'"
		distinct treatment
		estadd local n_treatment = "`=r(ndistinct)'"
		distinct authors 
		estadd local n_studies = "`=r(ndistinct)'"

	}
	
	#delimit ;
	esttab using "${paper_graph_folder}/table_A3.tex", replace keep(`vars') order(`vars') style(tex) substitute(_ \_) 
	cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.1 ** 0.05 *** 0.01) 
	stats(treatment_fe n_decisions n_id n_treatment n_studies N_clust , fmt(0) labels("Treatment FE" "$\#$ Decisions" "$\#$ Subjects" "$\#$ Treatments" "$\#$ Studies" "$\#$ Clusters" )) 
	label 
	extracols( 6 ) varwidth(35) mlabels(none ) collabels(none) eqlabels(none) 
	prehead("\begin{onehalfspace} \begin{small} \begin{center} { \begin{tabular}{l*{11}{c}} \hline \\ \multicolumn{4}{l}{Dependent variable: Standardized report} \\ \\ \\ ") 
	postfoot(" \hline \end{tabular} } \end{center} \begin{flushleft} Notes: OLS regressions. Robust standard errors clustered on individual subjects are in parentheses. The sample in each specification is restricted to those treatments in which the independent variable(s) vary. Significance at the 1, 5, and 10 percent level is denoted by ***, **, and *, respectively. \end{flushleft} \end{small} \end{onehalfspace}");
	#delimit cr
	
	
	
	
}	
		

	
{/*** Figure A.5 */
*******************************************************************************************	
		
	use truth_telling_meta_study_merged_data.dta, clear
	replaceFrequencies1D2asy
	
	keep if female != .
	bysort treatment: egen mean_female = mean(female)  // only keep studies that have not only men or only women
	keep if mean_female > 0 & mean_female < 1

	* we will use authors variable as part of variable name later, so drop all special characters 
	replace authors = subinstr(authors, ",", "", .)
	replace authors = subinstr(authors, "-", "", .)
	replace authors = subinstr(authors, " ", "", .)
	replace authors = substr(authors, 1, 20)
	
	*** collapse data
	gen subjects = 1
	collapse (mean) standardized_report_per_round (sum) subjects (first) citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by(id treatment authors female) // collapse to individual subjects (i.e., collapse multiple decisions within subject)
	replace subjects = 1 if id!= "" // for averages over individuals, treat as one observation and set frequency equal to 1. Leave frequency unchanged where no id as these are from handmade tables and do represent multiple people.
	collapse (mean) standardized_report_per_round (sum) subjects (first) citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by(treatment authors female) // collapse to treatment average

	bysort treatment: egen total_subjects = total(subjects)
	replace subjects = total_subjects

	* add legend as additional circles
	set obs `=_N + 6' 
	replace female = 0 in `=_N-5'/`=_N'
	replace female = 1 in `=_N'
	replace female = 1 in `=_N-2'
	replace female = 1 in `=_N-4'
	replace standardized_report_per_round = 0.75 in `=_N-5'/`=_N'
	replace standardized_report_per_round = -0.83 in `=_N'
	replace standardized_report_per_round = -0.89 in `=_N-2'
	replace standardized_report_per_round = -0.95 in `=_N-4'

	replace authors = "aaa_legend" in `=_N-5'/`=_N'
	replace subjects = 50 in `=_N-5'/`=_N-4'
	replace subjects = 100 in `=_N-3'/`=_N-2'
	replace subjects = 200 in `=_N-1'/`=_N'
	gen legend_label = ""
	replace legend_label = "50 subjects" in `=_N-5'/`=_N-4'
	replace legend_label = "100 subjects" in `=_N-3'/`=_N-2'
	replace legend_label = "200 subjects" in `=_N-1'/`=_N'
	
	replace treatment = 10050 in `=_N-5'/`=_N-4'
	replace treatment = 10100 in `=_N-3'/`=_N-2'
	replace treatment = 10200 in `=_N-1'/`=_N'
	
	
	gen temp_male_report = standardized_report_per_round if female == 0
	gen temp_female_report = standardized_report_per_round if female == 1
	bysort treatment: egen male_report = min(temp_male)
	bysort treatment: egen female_report = min(temp_female)
	
	* combine graph command 		
	local graph_command "twoway function y = x, range(-1 1) lcolor(black) lpattern(shortdash) " 
	encodeAndReplace authors
	levelsof authors
	foreach t in `r(levels)' {
		capture drop temp_male_`t' temp_female_`t' male_`t' female_`t' 
		qui gen male_`t' = male_report if authors == `t'
		qui gen female_`t' = female_report if authors == `t'
		
		local graph_command `"`graph_command' || scatter female_`t' male_`t' [weight=subjects], msize(*.3) "'
	}
	
	// add legend
	local graph_command `"`graph_command' || scatter female_1 male_1 [weight=subjects] if authors == "AAA_LEGEND":authors, msize(*.3) msymbol(none) mlabel(legend_label) mlabposition(3) mlabgap(*2) mlabsize(vsmall) mlabcolor(black)"'

	
	qui graph `graph_command' || , legend(off) graphregion(color(white)) ylabel(-1(0.5)1, nogrid) xlabel(-1(0.5)1, nogrid) ytitle("Standardized report: female") xtitle("Standardized report: male") yline(0, lcolor(black) lpattern(shortdash)) xline(0, lcolor(black) lpattern(shortdash))
	graph export "${paper_graph_folder}/figure_A5.png", width(3000) replace

	* export for website
	drop if authors == "AAA_LEGEND":authors
	keep male_* female_* authors female treatment standardized_report_per_round subjects citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink
	export delimited using "${website_export_folder}/data_iframe_4a.csv", replace 

	
	
}
	
	



	
{/*** Figure A.6 */
*******************************************************************************************	
	
	use truth_telling_meta_study_merged_data.dta, clear	
	
	keep if true_distribution == "1D6"
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases

	keep if female !=.
	
	distinct id
	gen subjects = cond(roundsimputed == 0, 1/total_reports, 1) // for "roundsimputed==1" data we have one line per subject and not total_reports lines
	collapse (sum) subjects (first) roundsimputed total_reports true_distribution citation payoff_mm repeated student remote internal_lying control_rolls true_distribution_text continent paper_title country weblink, by(female standardized_report_per_round) // collapse over id's within treatment and report
	
	total subjects
	
	bysort female: egen total_freq = total(subjects)
	
	gen actual_pdf = subjects/total_freq
	gen true_pdf = cond(true_distribution == "1D6", 1/6, cond(true_distribution=="1D2", 1/2, .))
		
	sort female standardized_report_per_round
	
	
	gen female_text = cond(female == 1, "F", "M")

	
	
	*** graph command
	local graph_command = "function y=1/6 , range(-1 1) lcolor(black) lpattern(shortdash) "

	
	levelsof female
	foreach q in `r(levels)' {
		capture drop pdf_`q'
		gen pdf_`q' = actual_pdf if female ==`q'
		local graph_command = `" scatter pdf_`q' standardized_report_per_round , msymbol(O) mfcolor(white) msize(*2) connect(l) lwidth(vvthin) mlabel(female_text) mlabcolor(black) mlabposition(0) || `graph_command' "'

	}
	
	
	`graph_command' xtitle("Standardized report") ytitle("Probability mass function") legend(off) plotregion( m(b=0) ) ylabel(0(0.2)0.4, nogrid) xlabel(-1 (.4) 1) graphregion(color(white)) note("") 
 
	graph export "${paper_graph_folder}/figure_A6.png", width(3000) replace

	
	
	*** export for website
	
	use truth_telling_meta_study_merged_data.dta, clear	
	
	keep if true_distribution == "1D6"
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
	keep if female !=.
	
	distinct id
	gen subjects = cond(roundsimputed == 0, 1/total_reports, 1) // for "roundsimputed==1" data we have one line per subject and not total_reports lines
		
	collapse (sum) subjects (first) total_reports true_distribution citation payoff_mm repeated student remote internal_lying control_rolls continent paper_title country weblink, by(female standardized_report_per_round treatment) // collapse over id's within treatment and report
	gen female_text = cond(female == 1, "F", "M")
	drop total_reports true_distribution 
		
	export delimited using "${website_export_folder}/data_iframe_4b.csv", replace 

	
}
	
	
	

	



{/*** Figure A.7 */
*******************************************************************************************	

	use truth_telling_meta_study_merged_data.dta, clear

	* keep uniform distributions
	keep if inlist(true_distribution, "1D2", "1D3", "1D6", "1D10")
	drop if inlist(treatment, "FFH 4.9":treatment, "JP BASELINE":treatment, "JP EXPLANATION":treatment, "JP TAX_FRAMING":treatment) // these treatments have non-linear increases
	drop if inlist(authors, "Blanco,Charness,Ezquerra,Rodriguez-Lara") // these treatments have non-linear increases
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // total_reports does not match data as treatments change from round to round

	* we weight the graph by subjects, i.e., each subject is weighted equally in the graph, independent of how many decisions they made
	gen frequency = cond(roundsimputed == 0, 1/total_reports, 1) // for "roundsimputed==1" data we have one line per subject and not total_reports lines
	replace standardized_report_per_round = round(standardized_report_per_round, 0.001)
	collapse (sum) frequency (first) report , by(true_distribution standardized_report_per_round) // collapse over id's within treatment and report


	* generate variables y-axis
	bysort true_distribution: egen total_freq = total(frequency) //total frequency per true_distribution
	gen actual_pdf = frequency/total_freq	//share of subjects reporting each point in the PDF
	gen true_pdf = cond(true_distribution == "1D6", 1/6, cond(true_distribution=="1D10", 1/10, cond(true_distribution == "1D2", 0.5, cond(true_distribution == "1D3", 1/3, .))))
	replace true_pdf = binomialp(4,report,0.5) if true_distribution == "4D2"
	replace true_pdf = binomialp(5,report,0.5) if true_distribution == "5D2"
	replace true_pdf = cond(report <= 7, report - 1, 13 - report)/36 if true_distribution == "2D6"
	assert true_pdf !=.
	gen true_dist_text = substr(true_distribution, 3, .) + " states"
	
	
	* calculate CI
	gen se = sqrt(actual_pdf*(1-actual_pdf)/total_freq)
	gen overall_pdf_lower_ci = actual_pdf - 1.96*se - true_pdf
	gen overall_pdf_upper_ci = actual_pdf + 1.96*se - true_pdf
	drop se
	
	encodeAndReplace true_distribution

	* add legend as additional circles
	set obs `=_N + 3' 
	replace actual_pdf = 0 in `=_N-2'/`=_N'	// this is used to place the legend vertically
	replace true_pdf = 0.25 in `=_N-2'		// this is used to place the legend vertically
	replace true_pdf = 0.265 in `=_N-1'		// this is used to place the legend vertically
	replace true_pdf = 0.28 in `=_N'		// this is used to place the legend vertically
	replace standardized_report_per_round = 0.65 in `=_N-2'/`=_N'	 // this is used to place the legend horizontally
	replace true_distribution = 10000 in `=_N-2'/`=_N'
	replace total_freq = 2000 in `=_N-2'
	replace total_freq = 1000 in `=_N-1'
	replace total_freq = 500 in `=_N'
	gen legend_label = ""
	replace legend_label = "2000 subjects (per study)" in `=_N-2'
	replace legend_label = "1000 subjects (per study)" in `=_N-1'
	replace legend_label = "500 subjects (per study)" in `=_N'	
	
	

	local graph_command = "function y=0 , range(-1 1.1) lcolor(black) lpattern(shortdash)"
	levelsof true_distribution
	foreach t in `r(levels)' { /* build graph command: one line per treatment */

		capture drop pdf_`t'_diff lower_ci_`t' upper_ci_`t'
		gen pdf_`t'_diff = actual_pdf - true_pdf if true_distribution ==`t'
		gen lower_ci_`t' = overall_pdf_lower_ci if true_distribution ==`t'
		gen upper_ci_`t' = overall_pdf_upper_ci if true_distribution ==`t'
		
		local connect_option = cond(`t' == 10000, "", "connect(l) lwidth(vvthin)") 
		local graph_command = "scatter pdf_`t'_diff standardized_report_per_round [weight=total_freq] , `connect_option' msize(*.3) || scatter pdf_`t'_diff standardized_report_per_round if standardized_report_per_round > 0.9 & standardized_report_per_round <= 1.0 , msymbol(none) mlabel(true_dist_text) mlabcolor(black) mlabsize(vsmall) || `graph_command' "
		local graph_command = `" `graph_command' || rcap lower_ci_`t' upper_ci_`t' standardized_report_per_round, color(black) lwidth(thin) "'

	}
	
	*add legend
	local graph_command `"`graph_command' || scatter pdf_10000_diff standardized_report_per_round [weight=total_freq] if true_distribution == 10000, msize(*.1) msymbol(none) mlabel(legend_label) mlabposition(3) mlabgap(*2) mlabsize(vsmall) mlabcolor(black)"'
	
	qui `graph_command' xtitle("Standardized report") ytitle("Difference between actual and true PMF") note("") legend(off) ylabel(-0.3(0.1)0.3, nogrid) graphregion(color(white))
	graph export "${paper_graph_folder}/figure_A7.png", width(3000) replace
	

}

	

	



{/*** Figure A.8 */
*******************************************************************************************	
	* hat tip to Felix Klimm

	global aux_file = "auxiliary_file_figure_A8.dta"
		
	use truth_telling_meta_study_merged_data.dta, clear
	
	* select 1D2 treatments with more than one round
	keep if true_distribution == "1D2" & total_reports > 1
	drop if roundsimputed == 1 //we import this data with handcoded tables below
	drop if inlist(authors,"Jiang2013","Jiang2015","PottersStoop") // total_reports does not match data

	* rearrange data
	collapse (sum) report (first) total_reports true_distribution citation weblink paper_title country , by(id treatment)

	gen frequency = 1
	rename total_reports rounds
	collapse (sum) frequency (first) rounds (first) citation weblink paper_title country, by(treatment report) 
	
	total frequency
	
	* generate line with frequency 0 if frequency of an outcome is 0
	egen tag = tag(treatment)
	expand rounds+2 if tag, gen(expanded)
	bysort treatment expanded: replace report = _n-1 if expanded
	replace frequency = 0 if expanded
	bysort treatment report: egen max_frequency = max(frequency)
	drop if round(frequency,0.001) < round(max_frequency, 0.001)
	
	total frequency // check that no subjects got added

	tostring treatment, replace force

	save12 "$aux_file", replace

	* Import additional handcoded data
 	appendHandCodedTableFigureA8, import_data_file("A8_CohnMarechal.xls")
	appendHandCodedTableFigureA8, import_data_file("A8_ArielyGarcia-RadaHornuffMannTafurt.xls")
	appendHandCodedTableFigureA8, import_data_file("A8_BraunHornuf.xls")
	appendHandCodedTableFigureA8, import_data_file("A8_CohnGescheMarechal.xls")

	
	* generate variables y-axis
	bysort treatment: egen total_freq = total(frequency) //total frequency per treatment
	sort treatment report
	gen actual_pdf = frequency/total_freq	//share of subjects reporting each point in the PDF
	gen true_pdf = binomialp(rounds,report,0.5) //binomial distribution of subjects reporting each point in the PDF
	assert true_pdf != .
	*gen diff_actual_true = (actual_pdf - true_pdf) //difference between actual and true pdf in percentage points
	
	* generate variable x-axis
	gen percent_success = report/rounds //normalize distributions from 0 to 100 percent
	
	* post share of subjects reporting always maximally or more than 80% of always maximally
	preserve
		bysort percent_success: egen subjects_at_this_perc_succ = total(frequency)
		duplicates drop percent_success, force
			
		total subjects_at_this_perc_succ 
		local all_subjects = _b[subjects_at_this_perc_succ]
		
		total subjects_at_this_perc_succ if percent_success == 1
		postToFile, file("stat_share_subjects_always_reporting_max") fmt("%5.1f") value(`=100*_b[subjects_at_this_perc_succ]/`all_subjects'')
		total subjects_at_this_perc_succ if percent_success > 0.81
		postToFile, file("stat_share_subjects_more_than_80_perc_reporting_max") fmt("%5.1f") value(`=100*_b[subjects_at_this_perc_succ]/`all_subjects'')
	restore
	
	encodeAndReplace treatment

	* add legend as additional circles
	set obs `=_N + 3' 
	replace actual_pdf = 0 in `=_N-2'/`=_N'
	replace true_pdf = 0.17 in `=_N-2'
	replace true_pdf = 0.1925 in `=_N-1'
	replace true_pdf = 0.215 in `=_N'
	replace percent_success = 0.875 in `=_N-2'/`=_N'
	replace treatment = 10000 in `=_N-2'/`=_N'
	replace frequency = 20 in `=_N-2'
	replace frequency = 10 in `=_N-1'
	replace frequency = 5 in `=_N'
	gen legend_label = ""
	replace legend_label = "20 subjects" in `=_N-2'
	replace legend_label = "10 subjects" in `=_N-1'
	replace legend_label = "5 subjects" in `=_N'	

	local graph_command = ""
	
	levelsof treatment
	foreach t in `r(levels)' { /* build graph command: one line per treatment */
		capture drop pdf_`t'_diff
		qui gen pdf_`t'_diff = (actual_pdf - true_pdf) if treatment ==`t'
		qui gen percent_`t'_diff = 100*pdf_`t'_diff // for website
		local connect_option = cond(`t' == 10000, "", "connect(l) lwidth(vvthin)") 
		local graph_command = "scatter pdf_`t'_diff percent_success [weight=frequency] , `connect_option' msize(*.2) || `graph_command' "
	}
	
	*add legend
	local graph_command `"`graph_command' scatter pdf_10000_diff percent_success [weight=frequency] if treatment == 10000, msize(*.6) msymbol(none) mlabel(legend_label) mlabposition(3) mlabgap(*2) mlabsize(vsmall) mlabcolor(black)"'

	qui `graph_command' || function y=0 , range(0 1) lcolor(black) lpattern(shortdash) xtitle("Share of high-payoff reports") ytitle("Difference between actual and truthful PMF") legend(off) ylabel(-0.2(0.1)0.4, nogrid) graphregion(color(white)) note("")
	graph export "${paper_graph_folder}/figure_A8.png", width(3000) replace


	* export for website
	drop if treatment == 10000
	gen percent_diff = 100*(actual_pdf - true_pdf)
	rename frequency subjects
	rename rounds total_reports
	
	keep percent_* subjects total_reports citation percent_success treatment legend_label percent_diff weblink paper_title country
	export delimited using "${website_export_folder}/data_iframe_6.csv", replace

	capture erase $aux_file

}	




	

{/*** Table A.4 */
*******************************************************************************************	


	use truth_telling_meta_study_merged_data.dta, clear

	collapse (first) bibtex treatment authors citation rawdata method_of_randomization publication_year country true_distribution, by(id) // collapse to one line per subjectt
	encodeAndReplace id
	collapse (count) id (first) bibtex authors citation rawdata method_of_randomization publication_year country true_distribution, by(treatment) // collapse to one line per treatment
	
	foreach var in true_distribution country method_of_randomization {
		egen tag_`var' = tag(authors `var') 
		bysort authors: egen n_`var' = total(tag_`var')
		replace `var' = "multiple" if n_`var' > 1
		replace `var' = "multiple (" + string(n_`var') + ")" if n_`var' > 1 & "`var'" == "country"
		
	}

	collapse (sum) id (count) treatment (first) bibtex citation rawdata method_of_randomization publication_year country true_distribution, by(authors) // collapse to one line per paper
		
	replace true_distribution = "1D6" if true_distribution == "1D6imputed"
	replace true_distribution = "asy. 1D2" if true_distribution == "1D2asy"
	replace country = "multiple (2)" if country == "Online (US and Indian users)"

	gen cite = substr(bibtex, strpos(bibtex, "{")+1, strpos(bibtex, ",") - strpos(bibtex, "{") -1)
	replace cite = "\cite{" + cite + "}"
	replace cite = cite + " *" if rawdata == 1


	order cite treatment id country method_of_randomization true_distribution
	sort cite
	replace cite = "this study *" if cite == "\cite{aabeler2017} *"

	
	drop authors publication_year rawdata bibtex citation
	
	label var cite "Study"
	label var treatment "$\#$ treatments"
	label var id "$\#$ subjects"
	label var country "Country"
	label var method_of_randomization "Randomization method"
	label var true_distribution "True distribution"
	
	
	foreach page in 1 2 {
	
		preserve
			
			if "`page'" == "1" {
				keep in f/42
				local notes = ""
			}
			if "`page'" == "2" {
				keep in 43/l
				local notes = "Notes: Studies for which we obtained the full raw data are marked by *. 1DX refers to a uniform distribution with X outcomes. A coin flip would thus be 1D2. ND2 refers to the distribution of the sum of N uniform random draws with two outcomes. Asymmetric 1D2 refers to distributions with two outcomes for which the two outcomes are not equally likely."
			}
			
			#delimit ;
			listtab_vars, delimiter(" & ") end("\\") substitute(varlab);
			listtab using "${paper_graph_folder}/table_A4_page`page'.tex", replace delimiter(" & ") end(" \\") 
			headlines("\begin{footnotesize} \begin{onehalfspace} \begin{center} \vspace*{-0.5cm} \hspace*{-2cm} \begin{tabular}{lccccc} \hline \hline `r(vars)' \hline")
			footlines("\hline \end{tabular} \end{center} \begin{flushleft} `notes' \end{flushleft} \end{onehalfspace} \end{footnotesize}")
			;
			#delimit cr
		restore
	
	}
	
	


	
}


