*******************************************
* 
*
* Helper programs for truth_telling_meta_study_programs_web_appendix.do
*
* Expects to be run from that do file.
*
* Contact for meta study: Johannes Abeler, johannes.abeler@economics.ox.ac.uk
*
* 
*
*
********************************************





{/* Save scalar to file for dynamic inclusion into LaTeX */
capture program drop postToFile
program define postToFile
	syntax , file(string) value(real) [fmt(string)]
	
	capture file close myfile
	
	file open myfile using "${paper_graph_folder}/`file'.tex", write replace text
	file write myfile `fmt' (`value')
	file write myfile "%" // to avoid trailing space in LateX
	file close myfile
	
	
end
}





{/* Read scalar from file (expects only one scalar followed by "%", as created by postToFile */
capture program drop readFromFile
program define readFromFile, rclass
	syntax , file(string) local(string) 
	
	if fileexists("${paper_graph_folder}/`file'.tex") {
		capture file close myfile
		file open myfile using "${paper_graph_folder}/`file'.tex", read text
		file read myfile data
		local data "`=substr("`data'", 1, strlen("`data'")-1)'" // drop trailing "%" inserted by postToFile
		file close myfile
		
		return scalar `local' = `data'
	}
	
end
}

	

	


{/* Count number of decisions taking into account rounds_imputed */
capture program drop countNumberDecisions
program define countNumberDecisions, rclass
	syntax [if/]
	return clear

	if `"`if'"' != `""' {
		local andif `"& `if'"'
	}
	else {
		local andif ""
	}
	

	qui count if roundsimputed == 0	`andif' // for these studies number of entries == number of decisions
	local decisions_not_imputed = r(N)
	
	qui sum total_reports if roundsimputed == 1 `andif', d // for these studies number of entries * total_reports == number of decision
	local all_decisions = r(sum) + `decisions_not_imputed'

	
	return scalar N = `all_decisions'
end
}





{/* Drop all treatment/authors that do not vary in the targetVar */
*** when we use treatment or authors FE, these observations would be dropped anyway but this makes clear from how many studies/obs the variation is coming from
capture program drop loadDataDropGroupsWOVariation
program define loadDataDropGroupsWOVariation
	syntax , targetVar(string) groupVar(string) [replaceFrequencies1D2asy(string)]
	
	use truth_telling_meta_study_merged_data.dta, clear
	if "`replaceFrequencies1D2asy'" != "no" replaceFrequencies1D2asy
	
	foreach var in `groupVar' `targetVar' id {
		capture confirm numeric variable `var'
		if _rc encodeAndReplace `var'
	}
	
	drop if `targetVar' == .
	
	// tag each level of the targetVar within the groupVar; if there is only one level within a groupVar, then no variation: drop
	egen tag = tag(`groupVar' `targetVar')
	bysort `groupVar': egen num_levels = total(tag)
	drop if num_levels == 1
	drop num_levels tag

	* we won't have access to round after collapsing, so have to do it here
	if "`targetVar'" == "info_about_past_others" & "`groupVar'" == "authors" drop if round == 1 & authors=="KROHER, WOLBRING":authors
	
	
end
}







{/* replaces frequences of 1D2asy distributions (i.e., distributions with two outcomes but with unequal likelihood) 
in order to make averages of standardized_report comparable. 
The resulting data set can only be used to calculate averages - the individual reports are misleading. */
capture program drop replaceFrequencies1D2asy
program define replaceFrequencies1D2asy

	set seed 123454321

	// sort observations within treatment and report randomly
	gen random_replace = runiform() 
	gsort +treat -standardized_report_per_round +random_replace

	qui levelsof treatment if true_distribution == "1D2asy"
	
	foreach treat in `r(levels)' {
		qui count if treatment == `treat' 
		local n = `r(N)'	// n.obs. per treatment
		qui count if treatment == `treat' & standardized_report_per_round == 1
		local n_high_report = `r(N)' // n.obs. of high report 
		qui sum winning_probability_if_1D2asy if treatment == `treat'
		local n_exp_high_report = `n' * `r(mean)' // n.obs. of high report expected under truth-telling
		local n_interim = `n' - `n_exp_high_report' // n.ob.s per treatment after taking out the expected high reports
		
		
		if `n_high_report' >= `n_exp_high_report' { // more high reports than expected under truthfulness
			*di "Treatment `treat' high: `n_high_report' expected: `n_exp_high_report'""
			// mark the expected number of high reports; pick the one to mark randomly to preserve unbiased average of covariates
			// random marking is done through random sorting above
			qui bysort treatment: gen to_be_replaced = 1 if treatment == `treat' & standardized_report_per_round == 1 & _n < `n_exp_high_report'

			// set low reports to standardized_report == 0 to get average correct in the end (ONLY WORKS FOR 1D2!!)
			qui replace standardized_report_per_round = 0 if standardized_report_per_round == -1 & treatment == `treat' 
			
			
			// replace sr of the to_be_replaced observations according to existing distribution of `treat'
			// this is done to preserve the number of observations
			qui replace random_replace = runiform()
			qui count if treatment == `treat' & standardized_report_per_round == 1 & to_be_replaced != 1
			local n_high_report_interim = `r(N)' // n.obs. of high report after taking out the expected high reports
			qui replace standardized_report_per_round = cond(random_replace < `n_high_report_interim'/`n_interim', 1, 0) if to_be_replaced == 1 & treatment == `treat' 
			
			capture drop to_be_replaced
			
				
		} 
		else {		
			di "`treat' is lying down on average - replaceFrequencies1D2asy does not deal with this case"
			exit
		}
			
	
	}

	capture drop random_replace

	// the following variables are now not correct anymore - correction above is only for standardized_report_per_round
	capture drop report standardized_report_acr_rounds 

end
}

 



{/* encodes a variable */
capture program drop encodeAndReplace
program define encodeAndReplace
	syntax varlist
	foreach var_name in `varlist' {
		replace `var_name' = strupper(`var_name')
		rename `var_name' tmp
		encode tmp, generate(`var_name')
		drop tmp
	}
end
}


{/* decodes a variable */
capture program drop decodeAndReplace
program define decodeAndReplace
	syntax varlist
	foreach var_name in `varlist' {
		rename `var_name' tmp
		decode tmp, generate(`var_name')
		drop tmp
	}
end
}



{/* Generates a variable and labels it */
* If the variable existed before, it will be dropped before the new generation 
* if `exp' is missing, the variable is generated with all missing values
capture program drop genAndLabel
program define genAndLabel
	syntax namelist(name=newvar) [=/exp] [, label(string)]
	
	capture confirm variable `newvar' // if variable exists already, drop it
	if _rc==0 {
		di "Variable `newvar' exists already: It will be dropped and replaced with new variable."
		drop `newvar'
	}

	if `"`exp'"' == `""' local exp = . // if exp is not specified, generate missing values

	
	generate `newvar' = `exp' 
	label variable `newvar' "`label'"
	
end
}




{/* save12 : Save all files in Stata 12 format */
capture program drop save12
program save12
 syntax anything(name=file) [, replace] 
 
 if `"`file'"' == `""' {
	di "No file name provided."
	exit
 }
 
 if floor(`c(stata_version)') == 12 {
	save `file', `replace'
 }
 else if floor(`c(stata_version)') == 13 {
	saveold `file', `replace'
 }
 else if floor(`c(stata_version)') == 14 {
	saveold `file', version(12) `replace' 
 }
 else {
	di "This Stata version is not supported. Update program save12"
	exit
 }
 
end
}




 {/* For Figure A8: Import table with additional data and append it */
	capture program drop appendHandCodedTableFigureA8
	program define appendHandCodedTableFigureA8
		syntax, import_data_file(string)

		import excel using "$folder/`import_data_file'", firstrow clear

		* check that necessary variables exist and are non-missing
		assert treatment != ""
		assert report != .
		assert frequency != .
		assert report != .
		
		* to keep variable labels of initial data set, we reverse append
		save12 temp_data_set.dta, replace
		use "$aux_file", clear
		append using temp_data_set.dta 
		erase temp_data_set.dta

		save12 "$aux_file", replace
		
	end
	}
	
	




	{/* collapseAll : Collapse variables, specifying variables to be collapsed (by), by (sum) and by (last), and collapsing all unspecified variables by (first) */
	*********************************************************************************************

	capture program drop collapseAll
	program define collapseAll
		syntax [, byVars(string) countVars(string) sumVars(string) meanVars(string) lastVars(string) ] 
		// string can use *, ?, etc.

		
		
		unab allVarList: _all
		capture : unab byVarList: `byVars'
		capture : unab countVarList: `countVars'
		capture : unab sumVarList: `sumVars'
		capture : unab meanVarList: `meanVars'
		capture : unab lastVarList: `lastVars'
	

		
		local firstVarList " `allVarList' " // space is important - it ensures that every variable name (including the last) is followed by a space which identifies a full variable name
		
		foreach VarList in byVarList countVarList sumVarList meanVarList lastVarList {
		
			tokenize "``VarList''" // Split each VarList into individual variable names and store in locals 1, 2, 3, etc.
			forvalues n = 1/20 {
				local firstVarList = subinstr("`firstVarList'"," ``n'' "," ",.) // If variable name occurs in firstVarList (with space before and after), replace it with a space.
				// Note that for n higher than the number of variables defined, local n will be undefined (i.e. defined as ""), so this looks for a double space which should not exist in the string
			}
			
		}
		

		// Code each portion of the collapse command individually -
		// Stata will not accept blank variable lists in the portion of the collapse command following (...), so need to remove the (...) as well if no variables are specified
		foreach stat in count sum mean last first { 
			if length("``stat'VarList'")>0 {
				local `stat'Command "(`stat') ``stat'VarList'"
			}
			else {
				local `stat'Command ""
			}
		}	
	

	
		* keep variables labels 
		foreach v of var * {
			local l`v' : variable label `v'
		}
	

		
		* keep all value labels (assuming that all value labels have the same name as their variable
		tempfile tf
		qui label save using `"`tf'"', replace
		
		qui label dir
		local list_of_valuelabels `r(names)'

		collapse `countCommand' `sumCommand' `meanCommand' `lastCommand' `firstCommand' , by(`byVarList') fast


		* copy variable labels back
		foreach v of var * {
			capture label var `v' "`l`v''"
		}
		

		*  this also takes quite long - drop unused variables
		* copy value labels back
		qui do `"`tf'"'
		foreach v in `list_of_valuelabels' {
			capture label values `v' `v'
		}
	 

		
	end
	}

	
	
	{/* prepare data set for regression and descriptive statistics tables */
	capture program drop prepareDatasetForTables
	program define prepareDatasetForTables	
	
		replace country = "other" if inlist(country, "", "Online (US and Indian users)") 

		replace true_distribution = "bell shaped" if inlist(true_distribution, "12D8", "2D2", "2D6", "30D6", "4D2", "5D2", "20D2", "30D2", "6D2")
		replace true_distribution = "other uniform" if inlist(true_distribution, "1D3", "1D6", "1D6imputed", "1D10", "1D100")
		
		foreach var in authors communication_channel country author_affiliation method_of_randomization true_distribution experiment_date info_about_past_others time_pressure id {
			capture encodeAndReplace `var'
		}


	end
	}
